@@ -20,9 +20,9 @@ conda update --yes conda
 
 conda init bash
 conda create -n testenv -yq
-conda install -n testenv -yq python=3.8 numpy scipy scikit-learn matplotlib pandas pytest pytest-xdist joblib nibabel cython requests
-conda install -c conda-forge python-kaleido
-conda install -c plotly plotly
+conda install -n testenv -yq python=3.8
 source activate testenv
 python -m pip install --user --upgrade --progress-bar off pip setuptools
-python -m pip install .
+# Install the local version of the library, along with both standard and testing-related dependencies
+# See setup.cfg for dependency group options
+python -m pip install .[plotting,plotly,test]
