@@ -3,14 +3,18 @@ from .niimg_conversions import (check_niimg, check_niimg_3d, concat_niimgs,
 
 from .niimg import _repr_niimgs, copy_img, load_niimg
 
+from .docs import fill_doc
+
 from .numpy_conversions import as_ndarray
 
 from .cache_mixin import CacheMixin
 
 from .logger import _compose_err_msg
-from nilearn._utils.helpers import replace_parameters
+from nilearn._utils.helpers import (rename_parameters, remove_parameters,
+                                    stringify_path)
 
 __all__ = ['check_niimg', 'check_niimg_3d', 'concat_niimgs', 'check_niimg_4d',
            '_repr_niimgs', 'copy_img', 'load_niimg',
-           'as_ndarray', 'CacheMixin', '_compose_err_msg', 'replace_parameters',
+           'as_ndarray', 'CacheMixin', '_compose_err_msg', 'rename_parameters',
+           'remove_parameters', 'fill_doc', 'stringify_path',
            ]
