@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Functions related to the documentation.
 
 docdict contains the standard documentation entries
@@ -16,12 +15,6 @@ import sys
 #
 docdict = dict()
 
-NILEARN_LINKS = {"landing_page": "http://nilearn.github.io"}
-NILEARN_LINKS["input_output"] = (
-    "{}/manipulating_images/input_output.html".format(
-        NILEARN_LINKS["landing_page"])
-)
-
 # Verbose
 verbose = """
 verbose : :obj:`int`, optional
@@ -30,6 +23,18 @@ verbose : :obj:`int`, optional
 docdict['verbose'] = verbose.format(1)
 docdict['verbose0'] = verbose.format(0)
 
+# ax
+docdict['ax'] = """
+ax : :class:`~matplotlib.axes.Axes`
+    The matplotlib axes in which the plots will be drawn."""
+
+# Legacy_format
+docdict['legacy_format'] = """
+legacy_format : :obj:`bool`, optional
+    If set to ``True``, the fetcher will return recarrays. Otherwise,
+    it will return pandas dataframes.
+    Default=True."""
+
 # Resume
 docdict['resume'] = """
 resume : :obj:`bool`, optional
@@ -54,9 +59,75 @@ url : :obj:`str`, optional
 docdict['smoothing_fwhm'] = """
 smoothing_fwhm : :obj:`float`, optional.
     If ``smoothing_fwhm`` is not ``None``, it gives
-    the full-width at half maximum in millimeters
+    the :term:`full-width at half maximum<FWHM>` in millimeters
     of the spatial smoothing to apply to the signal."""
 
+# Second_level_input
+docdict['second_level_input'] = """
+second_level_input : :obj:`list` of \
+:class:`~nilearn.glm.first_level.FirstLevelModel` objects \
+or :class:`pandas.DataFrame` or :obj:`list` of Niimg-like objects.
+
+    - Giving :class:`~nilearn.glm.first_level.FirstLevelModel` objects
+      will allow to easily compute the second level contrast of arbitrary first
+      level contrasts thanks to the ``first_level_contrast`` argument of
+      :meth:`~nilearn.glm.first_level.FirstLevelModel.compute_contrast`.
+      Effect size images will be computed for each model to contrast at
+      the second level.
+    - If a :class:`~pandas.DataFrame`, then it has to contain
+      ``subject_label``, ``map_name`` and ``effects_map_path``. It can
+      contain multiple maps that would be selected during contrast estimation
+      with the argument ``first_level_contrast`` of
+      :meth:`~nilearn.glm.first_level.FirstLevelModel.compute_contrast`.
+      The :class:`~pandas.DataFrame` will be sorted based on
+      the ``subject_label`` column to avoid order inconsistencies when
+      extracting the maps. So the rows of the automatically computed
+      design matrix, if not provided, will correspond to the sorted
+      ``subject_label`` column.
+    - If a :obj:`list` of Niimg-like objects then this is taken
+      literally as Y for the model fit and ``design_matrix`` must be
+      provided.
+
+"""
+
+# Second_level_contrast
+docdict['second_level_contrast'] = """
+second_level_contrast : :obj:`str` or :class:`numpy.ndarray` of shape\
+(n_col), optional
+    Where ``n_col`` is the number of columns of the design matrix.
+    The string can be a formula compatible with :meth:`pandas.DataFrame.eval`.
+    Basically one can use the name of the conditions as they appear in the
+    design matrix of the fitted model combined with operators +- and combined
+    with numbers with operators +-`*`/. The default (None) is accepted if the
+    design matrix has a single column, in which case the only possible
+    contrast array((1)) is applied; when the design matrix has multiple
+    columns, an error is raised."""
+
+# fwhm
+docdict['fwhm'] = """
+fwhm : scalar, :class:`numpy.ndarray`, or :obj:`tuple`, or :obj:`list`,\
+or 'fast' or None, optional
+    Smoothing strength, as a :term:`full-width at half maximum<FWHM>`,
+    in millimeters:
+
+        - If a nonzero scalar is given, width is identical in all 3 directions.
+        - If a :class:`numpy.ndarray`, :obj:`tuple`, or :obj:`list` is given,
+          it must have 3 elements, giving the :term:`FWHM` along each axis.
+          If any of the elements is zero or None, smoothing is not performed
+          along that axis.
+        - If `fwhm='fast'`, a fast smoothing will be performed with a filter
+          [0.2, 1, 0.2] in each direction and a normalisation to preserve the
+          local average value.
+        - If ``fwhm`` is None, no filtering is performed (useful when just
+          removal of non-finite values is needed).
+
+    .. note::
+
+        In corner case situations, `fwhm` is simply kept to None when `fwhm`
+        is specified as `fwhm=0`.
+
+"""
+
 # Standardize
 standardize = """
 standardize : :obj:`bool`, optional.
@@ -67,6 +138,19 @@ standardize : :obj:`bool`, optional.
 docdict['standardize'] = standardize.format('True')
 docdict['standardize_false'] = standardize.format('False')
 
+# standardize_confounds
+docdict['standardize_confounds'] = """
+standardize_confounds : :obj:`bool`, optional
+    If set to True, the confounds are z-scored: their mean is put
+    to 0 and their variance to 1 in the time dimension.
+    Default=True."""
+
+# ensure_finite
+docdict['ensure_finite'] = """
+ensure_finite : :obj:`bool`, optional
+    If True, the non-finite values (NANs and infs) found in the data
+    will be replaced by zeros."""
+
 # detrend
 docdict['detrend'] = """
 detrend : :obj:`bool`, optional
@@ -94,15 +178,75 @@ target_shape : :obj:`tuple` or :obj:`list`, optional.
 # Low_pass
 docdict['low_pass'] = """
 low_pass : :obj:`float` or None, optional
-    Low cutoff frequency in Hertz.
-    If None, no low-pass filtering will be performed.
-    Default=None."""
+    Low cutoff frequency in Hertz. If specified, signals above this
+    frequency will be filtered out. If None, no low-pass filtering
+    will be performed. Default=None."""
+
+# lower_cutoff
+docdict['lower_cutoff'] = """
+lower_cutoff : :obj:`float`, optional
+    Lower fraction of the histogram to be discarded."""
+
+# upper_cutoff
+docdict['upper_cutoff'] = """
+upper_cutoff : :obj:`float`, optional
+    Upper fraction of the histogram to be discarded."""
+
+# connected
+docdict['connected'] = """
+connected : :obj:`bool`, optional
+    If connected is True, only the largest connect component is kept."""
+
+# border_size
+docdict['border_size'] = """
+border_size : :obj:`int`, optional
+    The size, in :term:`voxel` of the border used on the side of
+    the image to determine the value of the background."""
+
+# opening
+docdict['opening'] = """
+opening : :obj:`bool` or :obj:`int`, optional
+    This parameter determines whether a morphological
+    :term:`opening<Opening>` is performed, to keep only large structures.
+    This step is useful to remove parts of the skull that might have been
+    included. ``opening`` can be:
+
+        - A boolean : If False, no :term:`opening<Opening>` is performed.
+          If True, it is equivalent to ``opening=1``.
+        - An integer `n`: The :term:`opening<Opening>` is performed via `n`
+          :term:`erosions<Erosion>` (see :func:`scipy.ndimage.binary_erosion`).
+          The largest connected component is then estimated if ``connected`` is
+          set to True, and 2`n` :term:`dilation<Dilation>` operations are
+          performed (see :func:`scipy.ndimage.binary_dilation`) followed by
+          `n` :term:`erosions<Erosion>`. This corresponds to 1
+          :term:`opening<Opening>` operation of order `n` followed by a
+          :term:`closing<Closing>` operator of order `n`.
+
+    .. note::
+
+        Turning off :term:`opening<Opening>` (``opening=False``) will also
+        prevent any smoothing applied to the image during the mask computation.
+
+"""
+
+# mask_type
+docdict['mask_type'] = """
+mask_type : {'whole-brain', 'gm', 'wm'}, optional
+    Type of mask to be computed:
+
+        - 'whole-brain': Computes the whole-brain mask.
+        - 'gm': Computes the grey-matter mask.
+        - 'wm': Computes the white-matter mask.
+
+    Default = 'whole-brain'.
+
+"""
 
 # High pass
 docdict['high_pass'] = """
 high_pass : :obj:`float`, optional
-    High cutoff frequency in Hertz.
-    Default=None."""
+    High cutoff frequency in Hertz. If specified, signals below this
+    frequency will be filtered out. Default=None."""
 
 # t_r
 docdict['t_r'] = """
@@ -118,7 +262,8 @@ mask_img : Niimg-like object
 
 # Memory
 docdict['memory'] = """
-memory : instance of :class:`joblib.Memory` or :obj:`str`
+memory : instance of :class:`joblib.Memory`, :obj:`str`, or \
+:class:`pathlib.Path`
     Used to cache the masking process.
     By default, no caching is done. If a :obj:`str` is given, it is the
     path to the caching directory."""
@@ -138,7 +283,7 @@ random_state : :obj:`int` or RandomState, optional
 memory_level = """
 memory_level : :obj:`int`, optional.
     Rough estimator of the amount of memory used by caching. Higher value
-    means more memory for caching.
+    means more memory for caching. Zero means no caching.
     Default={}."""
 docdict['memory_level'] = memory_level.format(0)
 docdict['memory_level1'] = memory_level.format(1)
@@ -154,14 +299,31 @@ docdict['n_jobs_all'] = n_jobs.format("-1")
 # img
 docdict['img'] = """
 img : Niimg-like object
-    See `input-output <%(input_output)s>`_.
-""" % NILEARN_LINKS
+    See :ref:`extracting_data`.
+"""
 
 # imgs
 docdict['imgs'] = """
 imgs : :obj:`list` of Niimg-like objects
-    See `input-output <%(input_output)s>`_.
-""" % NILEARN_LINKS
+    See :ref:`extracting_data`.
+"""
+
+# confounds
+docdict['confounds'] = """
+confounds : CSV file or array-like, optional
+    This parameter is passed to :func:`nilearn.signal.clean`.
+    Please see the related documentation for details.
+    shape: list of (number of scans, number of confounds)
+"""
+
+# sample_mask
+docdict['sample_mask'] = """
+sample_mask : Any type compatible with numpy-array indexing, optional
+    shape: (number of scans - number of volumes removed, )
+    Masks the niimgs along time/fourth dimension to perform scrubbing
+    (remove volumes with high motion) and/or non-steady-state volumes.
+    This parameter is passed to :func:`nilearn.signal.clean`.
+"""
 
 # cut_coords
 docdict['cut_coords'] = """
@@ -305,9 +467,9 @@ cbar_tick_format : :obj:`str`, optional
 # bg_img
 docdict['bg_img'] = """
 bg_img : Niimg-like object, optional
-    See `input_output <%(input_output)s>`_.
+    See :ref:`extracting_data`.
     The background image to plot on top of.
-""" % NILEARN_LINKS
+"""
 
 # vmin
 docdict['vmin'] = """
@@ -431,19 +593,60 @@ linewidths : :obj:`float`, optional
     Set the boundary thickness of the contours.
     Only reflects when ``view_type=contours``."""
 
+# hrf_model
+docdict['hrf_model'] = """
+hrf_model : :obj:`str`, function, list of functions, or None
+    This parameter defines the :term:`HRF` model to be used.
+    It can be a string if you are passing the name of a model
+    implemented in Nilearn.
+    Valid names are:
+
+        - 'spm': This is the :term:`HRF` model used in :term:`SPM`.
+          See :func:`nilearn.glm.first_level.spm_hrf`.
+        - 'spm + derivative': SPM model plus its time derivative.
+          This gives 2 regressors.
+          See :func:`nilearn.glm.first_level.spm_hrf`, and
+          :func:`nilearn.glm.first_level.spm_time_derivative`.
+        - 'spm + derivative + dispersion': Idem, plus dispersion
+          derivative. This gives 3 regressors.
+          See :func:`nilearn.glm.first_level.spm_hrf`,
+          :func:`nilearn.glm.first_level.spm_time_derivative`,
+          and :func:`nilearn.glm.first_level.spm_dispersion_derivative`.
+        - 'glover': This corresponds to the Glover :term:`HRF`.
+          See :func:`nilearn.glm.first_level.glover_hrf`.
+        - 'glover + derivative': The Glover :term:`HRF` + time
+          derivative. This gives 2 regressors.
+          See :func:`nilearn.glm.first_level.glover_hrf`, and
+          :func:`nilearn.glm.first_level.glover_time_derivative`.
+        - 'glover + derivative + dispersion': Idem, plus dispersion
+          derivative. This gives 3 regressors.
+          See :func:`nilearn.glm.first_level.glover_hrf`,
+          :func:`nilearn.glm.first_level.glover_time_derivative`, and
+          :func:`nilearn.glm.first_level.glover_dispersion_derivative`.
+        - 'fir': Finite impulse response basis. This is a set of
+          delayed dirac models.
+
+    It can also be a custom model. In this case, a function should
+    be provided for each regressor. Each function should behave as the
+    other models implemented within Nilearn. That is, it should take
+    both `t_r` and `oversampling` as inputs and return a sample numpy
+    array of appropriate shape.
+
+    .. note::
+        It is expected that `spm` standard and `glover` models would
+        not yield large differences in most cases.
+
+    .. note::
+        In case of `glover` and `spm` models, the derived regressors
+        are orthogonalized wrt the main one.
+
+"""
 # fsaverage options
 docdict['fsaverage_options'] = """
 
         - 'fsaverage3': the low-resolution fsaverage3 mesh (642 nodes)
         - 'fsaverage4': the low-resolution fsaverage4 mesh (2562 nodes)
         - 'fsaverage5': the low-resolution fsaverage5 mesh (10242 nodes)
-        - 'fsaverage5_sphere': the low-resolution fsaverage5 spheres
-
-            .. deprecated:: 0.8.0
-                This option has been deprecated and will be removed in v0.9.0.
-                fsaverage5 sphere coordinates can now be accessed through
-                attributes sphere_{left, right} using mesh='fsaverage5'
-
         - 'fsaverage6': the medium-resolution fsaverage6 mesh (40962 nodes)
         - 'fsaverage7': same as 'fsaverage'
         - 'fsaverage': the high-resolution fsaverage mesh (163842 nodes)
@@ -573,6 +776,15 @@ mask_strategy : {'background', 'epi', 'whole-brain-template',\
 
 """
 
+# templateflow
+docdict["templateflow"] = """
+    The default template of :term:`fMRIPrep` is the asymmetrical ICBM152 2009,
+    release c (MNI152NLin2009cSAsym). The NiLearn template is asymmetrical
+    ICBM152 2009, release a. If you wish to use the exact same release as
+    :term:`fMRIPrep`, please refer to TemplateFlow
+    (https://www.templateflow.org/).
+"""
+
 docdict_indented = {}
 
 
