@@ -10,13 +10,16 @@ import glob
 import nilearn as ni
 import numpy as np
 import itertools
-from sklearn.externals.joblib import Memory
+
+from joblib import Memory
 
 from .cache_mixin import cache
 from .niimg import _safe_get_data, load_niimg
-from .compat import _basestring, izip
+from .path_finding import _resolve_globbing
 
 from .exceptions import DimensionError
+from .niimg import _get_data
+from .helpers import stringify_path
 
 
 def _check_fov(img, affine, shape):
@@ -30,24 +33,24 @@ def _check_fov(img, affine, shape):
 
 def _check_same_fov(*args, **kwargs):
     """Returns True if provided images has the same field of view (shape and
-       affine). Returns False or raise an error elsewhere, depending on the
-       `raise_error` argument. This function can take an unlimited number of
-       images as arguments or keyword arguments and raise a user-friendly
-       ValueError if asked.
+    affine). Returns False or raise an error elsewhere, depending on the
+    `raise_error` argument. This function can take an unlimited number of
+    images as arguments or keyword arguments and raise a user-friendly
+    ValueError if asked.
 
     Parameters
     ----------
-
-    args: images
+    args : images
         Images to be checked. Images passed without keywords will be labelled
         as img_#1 in the error message (replace 1 with the appropriate index).
 
-    kwargs: images
+    kwargs : images
         Images to be checked. In case of error, images will be reference by
         their keyword name in the error message.
 
-    raise_error: boolean, optional
+    raise_error : boolean, optional
         If True, an error will be raised in case of error.
+
     """
     raise_error = kwargs.pop('raise_error', False)
     for i, arg in enumerate(args):
@@ -71,51 +74,55 @@ def _index_img(img, index):
 
     """Helper function for check_niimg_4d."""
     return new_img_like(
-        img, img.get_data()[:, :, :, index], img.affine,
+        img, _get_data(img)[:, :, :, index], img.affine,
         copy_header=True)
 
 
-def _resolve_globbing(path):
-    if isinstance(path, _basestring):
-        path_list = sorted(glob.glob(os.path.expanduser(path)))
-        # Raise an error in case the niimgs list is empty.
-        if len(path_list) == 0:
-            raise ValueError("No files matching path: %s" % path)
-        path = path_list
-
-    return path
-
-
 def _iter_check_niimg(niimgs, ensure_ndim=None, atleast_4d=False,
                       target_fov=None, dtype=None,
-                      memory=Memory(cachedir=None),
+                      memory=Memory(location=None),
                       memory_level=0, verbose=0):
     """Iterate over a list of niimgs and do sanity checks and resampling
 
     Parameters
     ----------
+    niimgs : list of niimg or glob pattern
+        Image to iterate over.
 
-    niimgs: list of niimg or glob pattern
-        Image to iterate over
-
-    ensure_ndim: integer, optional
+    ensure_ndim : integer, optional
         If specified, an error is raised if the data does not have the
         required dimension.
 
-    atleast_4d: boolean, optional
+    atleast_4d : boolean, optional
         If True, any 3D image is converted to a 4D single scan.
+        Default=False.
 
-    target_fov: tuple of affine and shape
-       If specified, images are resampled to this field of view
+    target_fov : tuple of affine and shape, optional
+       If specified, images are resampled to this field of view.
 
-    dtype: {dtype, "auto"}
+    dtype : {dtype, "auto"}, optional
         Data type toward which the data should be converted. If "auto", the
         data will be converted to int32 if dtype is discrete and float32 if it
         is continuous.
 
+    memory : instance of joblib.Memory or string, optional
+        Used to cache the masking process.
+        By default, no caching is done. If a string is given, it is the
+        path to the caching directory.
+        Default=Memory(location=None).
+
+    memory_level : integer, optional
+        Rough estimator of the amount of memory used by caching. Higher value
+        means more memory for caching. Default=0.
+
+    verbose : integer, optional
+        Indicate the level of verbosity. By default, nothing is printed.
+        Default=0.
+
     See also
     --------
         check_niimg, check_niimg_3d, check_niimg_4d
+
     """
     # If niimgs is a string, use glob to expand it to the matching filenames.
     niimgs = _resolve_globbing(niimgs)
@@ -164,7 +171,7 @@ def _iter_check_niimg(niimgs, ensure_ndim=None, atleast_4d=False,
             raise
         except TypeError as exc:
             img_name = ''
-            if isinstance(niimg, _basestring):
+            if isinstance(niimg, str):
                 img_name = " (%s) " % niimg
 
             exc.args = (('Error encountered while loading image #%d%s'
@@ -183,42 +190,47 @@ def check_niimg(niimg, ensure_ndim=None, atleast_4d=False, dtype=None,
 
     Parameters
     ----------
-    niimg: Niimg-like object
-        See http://nilearn.github.io/manipulating_images/input_output.html
-        If niimg is a string, consider it as a path to Nifti image and
-        call nibabel.load on it. The '~' symbol is expanded to the user home
-        folder.
-        If it is an object, check if the get_data() method
-        and affine attribute are present, raise TypeError otherwise.
+    niimg : Niimg-like object
+        See :ref:`extracting_data`.
+        If niimg is a string or pathlib.Path, consider it as a path to
+        Nifti image and call nibabel.load on it. The '~' symbol is expanded to
+        the user home folder.
+        If it is an object, check if the affine attribute present and that
+        nilearn.image.get_data returns a result, raise TypeError otherwise.
 
-    ensure_ndim: integer {3, 4}, optional
+    ensure_ndim : integer {3, 4}, optional
         Indicate the dimensionality of the expected niimg. An
         error is raised if the niimg is of another dimensionality.
 
-    atleast_4d: boolean, optional
+    atleast_4d : boolean, optional
         Indicates if a 3d image should be turned into a single-scan 4d niimg.
+        Default=False.
 
-    dtype: {dtype, "auto"}
+    dtype : {None, dtype, "auto"}, optional
         Data type toward which the data should be converted. If "auto", the
         data will be converted to int32 if dtype is discrete and float32 if it
-        is continuous.
+        is continuous. If None, data will not be converted to a new data type.
+        Default=None.
 
-    return_iterator: boolean, optional
-        Returns an iterator on the content of the niimg file input
+    return_iterator : boolean, optional
+        Returns an iterator on the content of the niimg file input.
+        Default=False.
 
-    wildcards: boolean, optional
+    wildcards : boolean, optional
         Use niimg as a regular expression to get a list of matching input
         filenames.
         If multiple files match, the returned list is sorted using an ascending
         order.
         If no file matches the regular expression, a ValueError exception is
         raised.
+        Default=True.
 
     Returns
     -------
-    result: 3D/4D Niimg-like object
+    result : 3D/4D Niimg-like object
         Result can be nibabel.Nifti1Image or the input, as-is. It is guaranteed
-        that the returned object has get_data() method and affine attribute.
+        that the returned object has an affine attribute and that its data can
+        be retrieved with nilearn.image.get_data.
 
     Notes
     -----
@@ -232,10 +244,13 @@ def check_niimg(niimg, ensure_ndim=None, atleast_4d=False, dtype=None,
     See also
     --------
         _iter_check_niimg, check_niimg_3d, check_niimg_4d
+
     """
     from ..image import new_img_like  # avoid circular imports
 
-    if isinstance(niimg, _basestring):
+    niimg = stringify_path(niimg)
+
+    if isinstance(niimg, str):
         if wildcards and ni.EXPAND_PATH_WILDCARDS:
             # Ascending sorting + expand user path
             filenames = sorted(glob.glob(os.path.expanduser(niimg)))
@@ -261,7 +276,7 @@ def check_niimg(niimg, ensure_ndim=None, atleast_4d=False, dtype=None,
             raise ValueError("File not found: '%s'" % niimg)
 
     # in case of an iterable
-    if hasattr(niimg, "__iter__") and not isinstance(niimg, _basestring):
+    if hasattr(niimg, "__iter__") and not isinstance(niimg, str):
         if return_iterator:
             return _iter_check_niimg(niimg, ensure_ndim=ensure_ndim,
                                      dtype=dtype)
@@ -276,7 +291,7 @@ def check_niimg(niimg, ensure_ndim=None, atleast_4d=False, dtype=None,
         affine = niimg.affine
         niimg = new_img_like(niimg, data[:, :, :, 0], affine)
     if atleast_4d and len(niimg.shape) == 3:
-        data = niimg.get_data().view()
+        data = _get_data(niimg).view()
         data.shape = data.shape + (1, )
         niimg = new_img_like(niimg, data, niimg.affine)
 
@@ -291,24 +306,27 @@ def check_niimg(niimg, ensure_ndim=None, atleast_4d=False, dtype=None,
 
 def check_niimg_3d(niimg, dtype=None):
     """Check that niimg is a proper 3D niimg-like object and load it.
+
     Parameters
     ----------
-    niimg: Niimg-like object
-        See http://nilearn.github.io/manipulating_images/input_output.html
+    niimg : Niimg-like object
+        See :ref:`extracting_data`.
         If niimg is a string, consider it as a path to Nifti image and
-        call nibabel.load on it. If it is an object, check if the get_data()
-        method and affine attribute are present, raise TypeError otherwise.
+        call nibabel.load on it.
+        If it is an object, check if the affine attribute present and that
+        nilearn.image.get_data returns a result, raise TypeError otherwise.
 
-    dtype: {dtype, "auto"}
+    dtype : {dtype, "auto"}, optional
         Data type toward which the data should be converted. If "auto", the
         data will be converted to int32 if dtype is discrete and float32 if it
         is continuous.
 
     Returns
     -------
-    result: 3D Niimg-like object
+    result : 3D Niimg-like object
         Result can be nibabel.Nifti1Image or the input, as-is. It is guaranteed
-        that the returned object has get_data() method and affine attribute.
+        that the returned object has an affine attribute and that its data can
+        be retrieved with nilearn.image.get_data.
 
     Notes
     -----
@@ -318,6 +336,7 @@ def check_niimg_3d(niimg, dtype=None):
     necessary.
 
     Its application is idempotent.
+
     """
     return check_niimg(niimg, ensure_ndim=3, dtype=dtype)
 
@@ -327,24 +346,26 @@ def check_niimg_4d(niimg, return_iterator=False, dtype=None):
 
     Parameters
     ----------
-    niimg: 4D Niimg-like object
-        See http://nilearn.github.io/manipulating_images/input_output.html
+    niimg : 4D Niimg-like object
+        See :ref:`extracting_data`.
         If niimgs is an iterable, checks if data is really 4D. Then,
         considering that it is a list of niimg and load them one by one.
         If niimg is a string, consider it as a path to Nifti image and
-        call nibabel.load on it. If it is an object, check if the get_data()
-        method and affine attribute are present, raise an Exception otherwise.
+        call nibabel.load on it.
+        If it is an object, check if the affine attribute present and that
+        nilearn.image.get_data returns a result, raise TypeError otherwise.
 
-    dtype: {dtype, "auto"}
+    dtype : {dtype, "auto"}, optional
         Data type toward which the data should be converted. If "auto", the
         data will be converted to int32 if dtype is discrete and float32 if it
         is continuous.
 
-    return_iterator: boolean
+    return_iterator : boolean, optional
         If True, an iterator of 3D images is returned. This reduces the memory
         usage when `niimgs` contains 3D images.
         If False, a single 4D image is returned. When `niimgs` contains 3D
         images they are concatenated together.
+        Default=False.
 
     Returns
     -------
@@ -356,13 +377,14 @@ def check_niimg_4d(niimg, return_iterator=False, dtype=None):
     with a session level.
 
     Its application is idempotent.
+
     """
     return check_niimg(niimg, ensure_ndim=4, return_iterator=return_iterator,
                        dtype=dtype)
 
 
 def concat_niimgs(niimgs, dtype=np.float32, ensure_ndim=None,
-                  memory=Memory(cachedir=None), memory_level=0,
+                  memory=Memory(location=None), memory_level=0,
                   auto_resample=False, verbose=0):
     """Concatenate a list of 3D/4D niimgs of varying lengths.
 
@@ -372,35 +394,38 @@ def concat_niimgs(niimgs, dtype=np.float32, ensure_ndim=None,
 
     Parameters
     ----------
-    niimgs: iterable of Niimg-like objects or glob pattern
-        See http://nilearn.github.io/manipulating_images/input_output.html
+    niimgs : iterable of Niimg-like objects or glob pattern
+        See :ref:`extracting_data`.
         Niimgs to concatenate.
 
-    dtype: numpy dtype, optional
-        the dtype of the returned image
+    dtype : numpy dtype, optional
+        The dtype of the returned image. Default=np.float32.
 
-    ensure_ndim: integer, optional
+    ensure_ndim : integer, optional
         Indicate the dimensionality of the expected niimg. An
         error is raised if the niimg is of another dimensionality.
 
-    auto_resample: boolean
+    auto_resample : boolean, optional
         Converts all images to the space of the first one.
+        Default=False.
 
-    verbose: int
+    verbose : int, optional
         Controls the amount of verbosity (0 means no messages).
+        Default=0.
 
-    memory : instance of joblib.Memory or string
+    memory : instance of joblib.Memory or string, optional
         Used to cache the resampling process.
         By default, no caching is done. If a string is given, it is the
         path to the caching directory.
+        Default=Memory(location=None).
 
     memory_level : integer, optional
         Rough estimator of the amount of memory used by caching. Higher value
-        means more memory for caching.
+        means more memory for caching. Default=0.
 
     Returns
     -------
-    concatenated: nibabel.Nifti1Image
+    concatenated : nibabel.Nifti1Image
         A single image.
 
     See Also
@@ -454,23 +479,23 @@ def concat_niimgs(niimgs, dtype=np.float32, ensure_ndim=None,
         lengths.append(niimg.shape[-1] if ndim == 4 else 1)
 
     target_shape = first_niimg.shape[:3]
-    if dtype == None:
-        dtype = first_niimg.get_data().dtype
+    if dtype is None:
+        dtype = _get_data(first_niimg).dtype
     data = np.ndarray(target_shape + (sum(lengths), ),
                       order="F", dtype=dtype)
     cur_4d_index = 0
-    for index, (size, niimg) in enumerate(izip(lengths, _iter_check_niimg(
+    for index, (size, niimg) in enumerate(zip(lengths, _iter_check_niimg(
             iterator, atleast_4d=True, target_fov=target_fov,
             memory=memory, memory_level=memory_level))):
 
         if verbose > 0:
-            if isinstance(niimg, _basestring):
+            if isinstance(niimg, str):
                 nii_str = "image " + niimg
             else:
                 nii_str = "image #" + str(index)
             print("Concatenating {0}: {1}".format(index + 1, nii_str))
 
-        data[..., cur_4d_index:cur_4d_index + size] = niimg.get_data()
+        data[..., cur_4d_index:cur_4d_index + size] = _get_data(niimg)
         cur_4d_index += size
 
     return new_img_like(first_niimg, data, first_niimg.affine, copy_header=True)
