@@ -4,8 +4,11 @@ Path finding utilities
 import glob
 import os.path
 
+from .helpers import stringify_path
+
 
 def _resolve_globbing(path):
+    path = stringify_path(path)
     if isinstance(path, str):
         path_list = sorted(glob.glob(os.path.expanduser(path)))
         # Raise an error in case the list is empty.
