@@ -165,7 +165,8 @@ def test_fetch_localizer_contrasts(tmp_path, request_mocker, localizer_mocker):
         ['checkerboard'],
         n_subjects=2,
         data_dir=tmp_path,
-        verbose=1)
+        verbose=1,
+        legacy_format=True)
     assert not hasattr(dataset, 'anats')
     assert not hasattr(dataset, 'tmaps')
     assert not hasattr(dataset, 'masks')
@@ -174,16 +175,31 @@ def test_fetch_localizer_contrasts(tmp_path, request_mocker, localizer_mocker):
     assert len(dataset.cmaps) == 2
     assert dataset.ext_vars.size == 2
 
+    dataset = func.fetch_localizer_contrasts(
+        ['checkerboard'],
+        n_subjects=2,
+        data_dir=tmp_path,
+        verbose=1,
+        legacy_format=False)
+    assert not hasattr(dataset, 'anats')
+    assert not hasattr(dataset, 'tmaps')
+    assert not hasattr(dataset, 'masks')
+    assert isinstance(dataset.cmaps[0], str)
+    assert isinstance(dataset.ext_vars, pd.DataFrame)
+    assert len(dataset.cmaps) == 2
+    assert len(dataset['ext_vars']) == 2
+
     # Multiple contrasts
     dataset = func.fetch_localizer_contrasts(
         ['checkerboard', 'horizontal checkerboard'],
         n_subjects=2,
         data_dir=tmp_path,
-        verbose=1)
-    assert isinstance(dataset.ext_vars, np.recarray)
+        verbose=1,
+        legacy_format=False)
+    assert isinstance(dataset.ext_vars, pd.DataFrame)
     assert isinstance(dataset.cmaps[0], str)
     assert len(dataset.cmaps) == 2 * 2  # two contrasts are fetched
-    assert dataset.ext_vars.size == 2
+    assert len(dataset['ext_vars']) == 2
 
     # all get_*=True
     dataset = func.fetch_localizer_contrasts(
@@ -193,13 +209,14 @@ def test_fetch_localizer_contrasts(tmp_path, request_mocker, localizer_mocker):
         get_anats=True,
         get_masks=True,
         get_tmaps=True,
-        verbose=1)
-    assert isinstance(dataset.ext_vars, np.recarray)
+        verbose=1,
+        legacy_format=False)
+    assert isinstance(dataset.ext_vars, pd.DataFrame)
     assert isinstance(dataset.anats[0], str)
     assert isinstance(dataset.cmaps[0], str)
     assert isinstance(dataset.masks[0], str)
     assert isinstance(dataset.tmaps[0], str)
-    assert dataset.ext_vars.size == 1
+    assert len(dataset['ext_vars']) == 1
     assert len(dataset.anats) == 1
     assert len(dataset.cmaps) == 1
     assert len(dataset.masks) == 1
@@ -211,11 +228,13 @@ def test_fetch_localizer_contrasts(tmp_path, request_mocker, localizer_mocker):
         ['checkerboard'],
         n_subjects=[2, 3, 5],
         data_dir=tmp_path,
-        verbose=1)
-    assert dataset2.ext_vars.size == 3
+        verbose=1,
+        legacy_format=False)
+    assert len(dataset2['ext_vars']) == 3
     assert len(dataset2.cmaps) == 3
-    assert ([row[0] for row in dataset2.ext_vars] ==
-                 [b'S02', b'S03', b'S05'])
+    assert (list(dataset2['ext_vars']['participant_id'].values) == ['S02',
+                                                                    'S03',
+                                                                    'S05'])
 
 
 def test_fetch_localizer_calculation_task(tmp_path, request_mocker,
@@ -224,7 +243,19 @@ def test_fetch_localizer_calculation_task(tmp_path, request_mocker,
     dataset = func.fetch_localizer_calculation_task(
         n_subjects=2,
         data_dir=tmp_path,
-        verbose=1)
+        verbose=1,
+        legacy_format=False)
+    assert isinstance(dataset.ext_vars, pd.DataFrame)
+    assert isinstance(dataset.cmaps[0], str)
+    assert len(dataset['ext_vars']) == 2
+    assert len(dataset.cmaps) == 2
+    assert dataset.description != ''
+
+    dataset = func.fetch_localizer_calculation_task(
+        n_subjects=2,
+        data_dir=tmp_path,
+        verbose=1,
+        legacy_format=True)
     assert isinstance(dataset.ext_vars, np.recarray)
     assert isinstance(dataset.cmaps[0], str)
     assert dataset.ext_vars.size == 2
@@ -251,23 +282,39 @@ def test_fetch_localizer_button_task(tmp_path, request_mocker,
     assert dataset.description != ''
 
 
-def test_fetch_abide_pcp(tmp_path, request_mocker):
-    ids = list(range(800))
-    filenames = ['no_filename'] * 800
-    filenames[::2] = ['filename'] * 400
-    pheno = pd.DataFrame({"subject_id": ids, "FILE_ID": filenames},
-                         columns=["subject_id", "FILE_ID"])
+@pytest.mark.parametrize("quality_checked", [False, True])
+def test_fetch_abide_pcp(tmp_path, request_mocker, quality_checked):
+    n_subjects = 800
+    ids = list(range(n_subjects))
+    filenames = ['no_filename'] * n_subjects
+    filenames[::2] = ['filename'] * int(n_subjects / 2)
+    qc_rater_1 = ['OK'] * n_subjects
+    qc_rater_1[::4] = ['fail'] * int(n_subjects / 4)
+    pheno = pd.DataFrame(
+        {"subject_id": ids,
+         "FILE_ID": filenames,
+         "qc_rater_1": qc_rater_1,
+         "qc_anat_rater_2": qc_rater_1,
+         "qc_func_rater_2": qc_rater_1,
+         "qc_anat_rater_3": qc_rater_1,
+         "qc_func_rater_3": qc_rater_1},
+        columns=[
+            "subject_id", "FILE_ID", "qc_rater_1",
+            "qc_anat_rater_2", "qc_func_rater_2",
+            "qc_anat_rater_3", "qc_func_rater_3"]
+    )
     request_mocker.url_mapping["*rocessed1.csv"] = pheno.to_csv(index=False)
 
     # All subjects
     dataset = func.fetch_abide_pcp(data_dir=tmp_path,
-                                   quality_checked=False, verbose=0)
-    assert len(dataset.func_preproc) == 400
+                                   quality_checked=quality_checked, verbose=0)
+    div = 4 if quality_checked else 2
+    assert len(dataset.func_preproc) == n_subjects / div
     assert dataset.description != ''
 
     # Smoke test using only a string, rather than a list of strings
     dataset = func.fetch_abide_pcp(data_dir=tmp_path,
-                                   quality_checked=False, verbose=0,
+                                   quality_checked=quality_checked, verbose=0,
                                    derivatives='func_preproc')
 
 
@@ -433,45 +480,6 @@ def _cobre_data(ids):
     return gzip.compress(csv.to_csv(index=False, sep="\t").encode("utf-8"))
 
 
-def test_fetch_cobre(tmp_path, request_mocker):
-    metadata, ids = _cobre_metadata()
-    request_mocker.url_mapping["*phenotypic_data.tsv.gz"] = _cobre_data(ids)
-    request_mocker.url_mapping["*articles/4197885"] = metadata
-
-    # All subjects
-    cobre_data = check_deprecation(
-        func.fetch_cobre, "'fetch_cobre' has been deprecated")(
-            n_subjects=None, data_dir=tmp_path)
-
-    phenotypic_names = ['func', 'confounds', 'phenotypic', 'description',
-                        'desc_con', 'desc_phenotypic']
-
-    # test length of functional filenames to max 146
-    assert len(cobre_data.func) == 146
-    # test length of corresponding confounds files of same length to max 146
-    assert len(cobre_data.confounds) == 146
-    # test return type variables
-    assert sorted(cobre_data) == sorted(phenotypic_names)
-    # test functional filenames in a list
-    assert isinstance(cobre_data.func, list)
-    # test confounds files in a list
-    assert isinstance(cobre_data.confounds, list)
-    assert isinstance(cobre_data.func[0], str)
-    # returned phenotypic data will be an array
-    assert isinstance(cobre_data.phenotypic, np.recarray)
-
-    # Fetch only 30 subjects
-    data_30_subjects = func.fetch_cobre(n_subjects=30,
-                                        data_dir=tmp_path)
-    assert len(data_30_subjects.func) == 30
-    assert len(data_30_subjects.confounds) == 30
-
-    # Test more than maximum subjects
-    test_150_subjects = func.fetch_cobre(n_subjects=150,
-                                         data_dir=tmp_path)
-    assert len(test_150_subjects.func) == 146
-
-
 def test_fetch_surf_nki_enhanced(tmp_path, request_mocker, verbose=0):
 
     ids = np.asarray(['A00028185', 'A00035827', 'A00037511', 'A00039431',
@@ -680,7 +688,7 @@ def test_select_from_index(request_mocker):
     assert data_prefix + '/sub-xxx/ses-02_task-rest.txt' in new_urls
 
 
-def test_fetch_openneuro_dataset_index(request_mocker):
+def test_fetch_ds000030_urls(request_mocker):
     with TemporaryDirectory() as tmpdir:
         dataset_version = 'ds000030_R1.0.4'
         subdir_names = ['ds000030', 'ds000030_R1.0.4', 'uncompressed']
@@ -694,35 +702,70 @@ def test_fetch_openneuro_dataset_index(request_mocker):
         mock_json_content = ['junk1', 'junk2']
         with open(filepath, 'w') as f:
             json.dump(mock_json_content, f)
-        urls_path, urls = func.fetch_openneuro_dataset_index(
+
+        # fetch_ds000030_urls should retrieve the appropriate URLs
+        urls_path, urls = func.fetch_ds000030_urls(
             data_dir=tmpdir,
-            dataset_version=dataset_version,
             verbose=1,
         )
         urls_path = urls_path.replace('/', os.sep)
         assert urls_path == filepath
         assert urls == mock_json_content
 
+        # fetch_openneuro_dataset_index should do the same, but with a warning
+        with pytest.warns(DeprecationWarning):
+            urls_path, urls = func.fetch_openneuro_dataset_index(
+                data_dir=tmpdir,
+                dataset_version=dataset_version,
+                verbose=1,
+            )
+
+        urls_path = urls_path.replace('/', os.sep)
+        assert urls_path == filepath
+        assert urls == mock_json_content
+
+        # fetch_openneuro_dataset_index should even grab ds000030 when you
+        # provide a different dataset name
+        with pytest.warns(
+            UserWarning,
+            match='"ds000030_R1.0.4" will be downloaded',
+        ):
+            urls_path, urls = func.fetch_openneuro_dataset_index(
+                data_dir=tmpdir,
+                dataset_version='ds500_v2',
+                verbose=1,
+            )
+
+        urls_path = urls_path.replace('/', os.sep)
+        assert urls_path == filepath
+        assert urls == mock_json_content
+
 
 def test_fetch_openneuro_dataset(request_mocker, tmp_path):
     dataset_version = 'ds000030_R1.0.4'
     data_prefix = '{}/{}/uncompressed'.format(
-        dataset_version.split('_')[0], dataset_version)
-    data_dir = _get_dataset_dir(data_prefix, data_dir=tmp_path,
-                                verbose=1)
+        dataset_version.split('_')[0],
+        dataset_version,
+    )
+    data_dir = _get_dataset_dir(
+        data_prefix,
+        data_dir=tmp_path,
+        verbose=1,
+    )
     url_file = os.path.join(data_dir, 'urls.json')
+
     # Prepare url files for subject and filter tests
     urls = [
-        "https://example.com/{}/stuff.html" + data_prefix + '',
-        "https://example.com/{}/sub-xxx.html",
-        "https://example.com/{}/sub-yyy.html",
-        "https://example.com/{}/sub-xxx/ses-01_task-rest.txt",
-        "https://example.com/{}/sub-xxx/ses-01_task-other.txt",
-        "https://example.com/{}/sub-xxx/ses-02_task-rest.txt",
-        "https://example.com/{}/sub-xxx/ses-02_task-other.txt",
-        "https://example.com/{}/sub-yyy/ses-01.txt",
-        "https://example.com/{}/sub-yyy/ses-02.txt"]
-    urls = [url.format(data_prefix) for url in urls]
+        f'https://example.com/{data_prefix}/stuff.html',
+        f'https://example.com/{data_prefix}/sub-xxx.html',
+        f'https://example.com/{data_prefix}/sub-yyy.html',
+        f'https://example.com/{data_prefix}/sub-xxx/ses-01_task-rest.txt',
+        f'https://example.com/{data_prefix}/sub-xxx/ses-01_task-other.txt',
+        f'https://example.com/{data_prefix}/sub-xxx/ses-02_task-rest.txt',
+        f'https://example.com/{data_prefix}/sub-xxx/ses-02_task-other.txt',
+        f'https://example.com/{data_prefix}/sub-yyy/ses-01.txt',
+        f'https://example.com/{data_prefix}/sub-yyy/ses-02.txt',
+    ]
     json.dump(urls, open(url_file, 'w'))
 
     # Only 1 subject and not subject specific files get downloaded
@@ -732,6 +775,27 @@ def test_fetch_openneuro_dataset(request_mocker, tmp_path):
     assert isinstance(dl_files, list)
     assert len(dl_files) == 9
 
+    # URLs do not contain the data_prefix, which should raise a ValueError
+    urls = [
+        'https://example.com/stuff.html',
+        'https://example.com/sub-yyy/ses-01.txt',
+    ]
+    with pytest.raises(ValueError, match='This indicates that the URLs'):
+        func.fetch_openneuro_dataset(urls, tmp_path, dataset_version)
+
+    # Try downloading a different dataset without providing URLs
+    # This should raise a warning and download ds000030.
+    with pytest.warns(
+        UserWarning,
+        match='Downloading "ds000030_R1.0.4".',
+    ):
+        urls_path, urls = func.fetch_openneuro_dataset(
+            urls=None,
+            data_dir=tmp_path,
+            dataset_version='ds500_v2',
+            verbose=1,
+        )
+
 
 def test_fetch_localizer(request_mocker, tmp_path):
     dataset = func.fetch_localizer_first_level(data_dir=tmp_path)
