@@ -21,7 +21,7 @@ from joblib import Parallel, delayed
 from nilearn._utils import CacheMixin, fill_doc
 from nilearn._utils.cache_mixin import _check_memory
 from nilearn._utils.param_validation import check_feature_screening
-from nilearn.input_data.masker_validation import check_embedded_nifti_masker
+from nilearn.maskers._masker_validation import _check_embedded_nifti_masker
 from nilearn.regions.rena_clustering import ReNA
 from sklearn import clone
 from sklearn.dummy import DummyClassifier, DummyRegressor
@@ -45,16 +45,16 @@ except ImportError:
 
 
 SUPPORTED_ESTIMATORS = dict(
-    svc_l1=LinearSVC(penalty='l1', dual=False, max_iter=1e4),
-    svc_l2=LinearSVC(penalty='l2', max_iter=1e4),
-    svc=LinearSVC(penalty='l2', max_iter=1e4),
+    svc_l1=LinearSVC(penalty='l1', dual=False, max_iter=10000),
+    svc_l2=LinearSVC(penalty='l2', max_iter=10000),
+    svc=LinearSVC(penalty='l2', max_iter=10000),
     logistic_l1=LogisticRegression(penalty='l1', solver='liblinear'),
     logistic_l2=LogisticRegression(penalty='l2', solver='liblinear'),
     logistic=LogisticRegression(penalty='l2', solver='liblinear'),
     ridge_classifier=RidgeClassifierCV(),
     ridge_regressor=RidgeCV(),
     ridge=RidgeCV(),
-    svr=SVR(kernel='linear', max_iter=1e4),
+    svr=SVR(kernel='linear', max_iter=10000),
     dummy_classifier=DummyClassifier(strategy='stratified',
                                      random_state=0),
     dummy_regressor=DummyRegressor(strategy='mean'),
@@ -361,7 +361,7 @@ class _BaseDecoder(LinearRegression, CacheMixin):
         Parameters
         ----------
         X: list of Niimg-like objects
-            See http://nilearn.github.io/manipulating_images/input_output.html
+            See :ref:`extracting_data`.
             Data on which model is to be fitted. If this is a list,
             the affine is considered the same for all.
 
@@ -593,8 +593,7 @@ class _BaseDecoder(LinearRegression, CacheMixin):
         Parameters
         ----------
         X: list of Niimg-like objects
-            See
-            <http://nilearn.github.io/manipulating_images/input_output.html>
+            See :ref:`extracting_data`.
             Data on prediction is to be made. If this is a list,
             the affine is considered the same for all.
 
@@ -654,7 +653,7 @@ class _BaseDecoder(LinearRegression, CacheMixin):
 
     def _apply_mask(self, X):
         # Nifti masking
-        self.masker_ = check_embedded_nifti_masker(self, multi_subject=False)
+        self.masker_ = _check_embedded_nifti_masker(self, multi_subject=False)
         X = self.masker_.fit_transform(X)
         self.mask_img_ = self.masker_.mask_img_
 
@@ -998,7 +997,7 @@ class FREMRegressor(_BaseDecoder):
     FREM uses an implicit spatial regularization through fast clustering and
     aggregates a high number of estimators trained on various splits of the
     training set, thus returning a very robust decoder at a lower computational
-    cost than other spatially regularized methods :footcite:`HOYOSIDROBO2018160`.
+    cost than other spatially regularized methods :footcite:`Hoyos-Idrobo2018`.
 
     Parameters
     -----------
@@ -1121,7 +1120,7 @@ class FREMClassifier(_BaseDecoder):
     FREM uses an implicit spatial regularization through fast clustering and
     aggregates a high number of estimators trained on various splits of the
     training set, thus returning a very robust decoder at a lower computational
-    cost than other spatially regularized methods :footcite:`HOYOSIDROBO2018160`.
+    cost than other spatially regularized methods :footcite:`Hoyos-Idrobo2018`.
 
     Parameters
     -----------
