@@ -23,7 +23,7 @@ from sklearn.exceptions import ConvergenceWarning
 
 from .. import masking
 from ..image.resampling import coord_transform
-from ..input_data.nifti_spheres_masker import _apply_mask_and_get_affinity
+from nilearn.maskers.nifti_spheres_masker import _apply_mask_and_get_affinity
 from .._utils import check_niimg_4d, fill_doc
 from sklearn.model_selection import cross_val_score
 
@@ -88,7 +88,7 @@ def search_light(X, y, estimator, A, groups=None, scoring=None,
 
 
 @fill_doc
-class GroupIterator(object):
+class GroupIterator:
     """Group iterator
 
     Provides group of features for search_light loop
@@ -199,12 +199,12 @@ class SearchLight(BaseEstimator):
     Parameters
     -----------
     mask_img : Niimg-like object
-        See http://nilearn.github.io/manipulating_images/input_output.html
-        boolean image giving location of voxels containing usable signals.
+        See :ref:`extracting_data`.
+        Boolean image giving location of voxels containing usable signals.
 
     process_mask_img : Niimg-like object, optional
-        See http://nilearn.github.io/manipulating_images/input_output.html
-        boolean image giving voxels on which searchlight should be
+        See :ref:`extracting_data`.
+        Boolean image giving voxels on which searchlight should be
         computed.
 
     radius : float, optional
@@ -263,7 +263,7 @@ class SearchLight(BaseEstimator):
         Parameters
         ----------
         imgs : Niimg-like object
-            See http://nilearn.github.io/manipulating_images/input_output.html
+            See :ref:`extracting_data`.
             4D image.
 
         y : 1D array-like
