@@ -236,7 +236,7 @@ def test_lasso_vs_graph_net():
     # Test for one of the extreme cases of Graph-Net: That is, with
     # l1_ratio = 1 (pure Lasso), we compare Graph-Net's performance with
     # Scikit-Learn lasso
-    lasso = Lasso(max_iter=100, tol=1e-8, normalize=False)
+    lasso = Lasso(max_iter=100, tol=1e-8)
     graph_net = BaseSpaceNet(mask=mask, alphas=1. * X_.shape[0],
                              l1_ratios=1, is_classif=False,
                              penalty="graph-net", max_iter=100)
