@@ -15,12 +15,12 @@ from sklearn.decomposition import fastica
 from joblib import Memory, delayed, Parallel
 from sklearn.utils import check_random_state
 
-from .multi_pca import MultiPCA
+from ._multi_pca import _MultiPCA
 from nilearn._utils import fill_doc
 
 
 @fill_doc
-class CanICA(MultiPCA):
+class CanICA(_MultiPCA):
     """Perform Canonical Independent Component Analysis [1]_ [2]_.
 
     Parameters
@@ -33,10 +33,8 @@ class CanICA(MultiPCA):
 
     n_components : int, optional
         Number of components to extract. Default=20.
-
-    smoothing_fwhm : float, optional
-        If smoothing_fwhm is not None, it gives the size in millimeters of the
-        spatial smoothing to apply to the signal. Default=6mm.
+    %(smoothing_fwhm)s
+        Default=6mm.
 
     do_cca : boolean, optional
         Indicate if a Canonical Correlation Analysis must be run after the
@@ -150,7 +148,7 @@ class CanICA(MultiPCA):
         of `mask` and other NiftiMasker related parameters as initialization.
 
     `mask_img_` : Niimg-like object
-        See http://nilearn.github.io/manipulating_images/input_output.html
+        See :ref:`extracting_data`.
         The mask of the data. If no mask was given at masker creation, contains
         the automatically computed mask.
 
@@ -253,7 +251,7 @@ class CanICA(MultiPCA):
             self.components_img_ = self.masker_.inverse_transform(
                 self.components_)
 
-    # Overriding MultiPCA._raw_fit overrides MultiPCA.fit behavior
+    # Overriding _MultiPCA._raw_fit overrides _MultiPCA.fit behavior
     def _raw_fit(self, data):
         """Helper function that directly process unmasked data.
 
@@ -266,6 +264,6 @@ class CanICA(MultiPCA):
             Unmasked data to process
 
         """
-        components = MultiPCA._raw_fit(self, data)
+        components = _MultiPCA._raw_fit(self, data)
         self._unmix_components(components)
         return self
