@@ -7,8 +7,6 @@ constitutes output maps
 # Author: Arthur Mensch
 # License: BSD 3 clause
 
-from __future__ import division
-
 import warnings
 
 import numpy as np
@@ -16,7 +14,7 @@ from sklearn.decomposition import dict_learning_online
 from joblib import Memory
 from sklearn.linear_model import Ridge
 
-from .base import BaseDecomposition
+from ._base import _BaseDecomposition
 from .canica import CanICA
 from nilearn._utils import fill_doc
 
@@ -25,7 +23,7 @@ sparse_encode_args = {'check_input': False}
 
 
 def _compute_loadings(components, data):
-    ridge = Ridge(fit_intercept=None, alpha=1e-8)
+    ridge = Ridge(fit_intercept=False, alpha=1e-8)
     ridge.fit(components.T, np.asarray(data.T))
     loadings = ridge.coef_.T
 
@@ -36,9 +34,10 @@ def _compute_loadings(components, data):
 
 
 @fill_doc
-class DictLearning(BaseDecomposition):
+class DictLearning(_BaseDecomposition):
     """Perform a map learning algorithm based on spatial component sparsity,
-    over a CanICA initialization [1]_.  This yields more stable maps than CanICA.
+    over a :term:`CanICA` initialization [1]_.
+    This yields more stable maps than :term:`CanICA`.
 
      .. versionadded:: 0.2
 
@@ -83,10 +82,8 @@ class DictLearning(BaseDecomposition):
 
     random_state : int or RandomState, optional
         Pseudo number generator state used for random sampling.
-
-    smoothing_fwhm : float, optional
-        If smoothing_fwhm is not None, it gives the size in millimeters of the
-        spatial smoothing to apply to the signal. Default=4mm.
+    %(smoothing_fwhm)s
+        Default=4mm.
 
     standardize : boolean, optional
         If standardize is True, the time-series are centered and normed:
@@ -171,7 +168,7 @@ class DictLearning(BaseDecomposition):
         of `mask` and other NiftiMasker related parameters as initialization.
 
     `mask_img_` : Niimg-like object
-        See http://nilearn.github.io/manipulating_images/input_output.html
+        See :ref:`extracting_data`.
         The mask of the data. If no mask was given at masker creation, contains
         the automatically computed mask.
 
@@ -192,17 +189,17 @@ class DictLearning(BaseDecomposition):
                  target_shape=None, mask_strategy='epi', mask_args=None,
                  n_jobs=1, verbose=0, memory=Memory(location=None),
                  memory_level=0):
-        BaseDecomposition.__init__(self, n_components=n_components,
-                                   random_state=random_state, mask=mask,
-                                   smoothing_fwhm=smoothing_fwhm,
-                                   standardize=standardize, detrend=detrend,
-                                   low_pass=low_pass, high_pass=high_pass,
-                                   t_r=t_r, target_affine=target_affine,
-                                   target_shape=target_shape,
-                                   mask_strategy=mask_strategy,
-                                   mask_args=mask_args, memory=memory,
-                                   memory_level=memory_level, n_jobs=n_jobs,
-                                   verbose=verbose)
+        _BaseDecomposition.__init__(self, n_components=n_components,
+                                    random_state=random_state, mask=mask,
+                                    smoothing_fwhm=smoothing_fwhm,
+                                    standardize=standardize, detrend=detrend,
+                                    low_pass=low_pass, high_pass=high_pass,
+                                    t_r=t_r, target_affine=target_affine,
+                                    target_shape=target_shape,
+                                    mask_strategy=mask_strategy,
+                                    mask_args=mask_args, memory=memory,
+                                    memory_level=memory_level, n_jobs=n_jobs,
+                                    verbose=verbose)
         self.n_epochs = n_epochs
         self.batch_size = batch_size
         self.method = method
