@@ -10,7 +10,7 @@ import nibabel
 from nilearn._utils.testing import write_tmp_imgs
 
 from nilearn.decomposition.canica import CanICA
-from nilearn.input_data import MultiNiftiMasker
+from nilearn.maskers import MultiNiftiMasker
 from nilearn.image import iter_img
 from nilearn.decomposition.tests.test_multi_pca import _tmp_dir
 from nilearn.image import get_data
@@ -60,14 +60,14 @@ def _make_canica_components(shape):
                       component3.ravel(), component4.ravel()))
 
 
-def _make_canica_test_data(rng=None, n_subjects=8, noisy=False):
+def _make_canica_test_data(rng=None, n_subjects=8, noisy=True):
     if rng is None:
         rng = np.random.RandomState(0)
     shape = (30, 30, 5)
     affine = np.eye(4)
     components = _make_canica_components(shape)
     if noisy:  # Creating noisy non positive data
-        components[rng.randn(*components.shape) > .8] *= -5.
+        components[rng.randn(*components.shape) > .8] *= -2.
 
     for mp in components:
         assert mp.max() <= -mp.min()  # Goal met ?
