@@ -1,9 +1,6 @@
 """
-This module presents an interface to use the glm implemented in
-nistats.regression.
-
-It contains the GLM and contrast classes that are meant to be the main objects
-of fMRI data analyses.
+This module contains the GLM and contrast classes that are meant to be the main
+objects of fMRI data analyses.
 
 Author: Bertrand Thirion, Martin Perez-Guevara, 2016
 
@@ -19,14 +16,15 @@ import numpy as np
 import pandas as pd
 from joblib import Memory, Parallel, delayed
 from nibabel import Nifti1Image
-from nibabel.onetime import auto_attr
 from sklearn.base import clone
 from sklearn.cluster import KMeans
 
+from nilearn.interfaces.bids import get_bids_files, parse_bids_filename
+from nilearn._utils import fill_doc
 from nilearn._utils.glm import (_check_events_file_uses_tab_separators,
-                                _check_run_tables, get_bids_files,
-                                parse_bids_filename)
+                                _check_run_tables, _check_run_sample_masks)
 from nilearn._utils.niimg_conversions import check_niimg
+from nilearn._utils import stringify_path
 from nilearn.glm.contrasts import (_compute_fixed_effect_contrast,
                                    expression_to_contrast_vector)
 from nilearn.glm.first_level.design_matrix import \
@@ -101,7 +99,8 @@ def _yule_walker(x, order):
     return rho
 
 
-def run_glm(Y, X, noise_model='ar1', bins=100, n_jobs=1, verbose=0):
+def run_glm(Y, X, noise_model='ar1', bins=100,
+            n_jobs=1, verbose=0, random_state=None):
     """ GLM fit for an fMRI data matrix
 
     Parameters
@@ -133,6 +132,12 @@ def run_glm(Y, X, noise_model='ar1', bins=100, n_jobs=1, verbose=0):
     verbose : int, optional
         The verbosity level. Default=0.
 
+    random_state : int or numpy.random.RandomState, optional
+        Random state seed to sklearn.cluster.KMeans for autoregressive models
+        of order at least 2 ('ar(N)' with n >= 2). Default=None.
+
+        .. versionadded:: 0.9.1
+
     Returns
     -------
     labels : array of shape (n_voxels,),
@@ -183,7 +188,8 @@ def run_glm(Y, X, noise_model='ar1', bins=100, n_jobs=1, verbose=0):
             labels = np.array([str(val) for val in ar_coef_])
         else:  # AR(N>1) case
             n_clusters = np.min([bins, Y.shape[1]])
-            kmeans = KMeans(n_clusters=n_clusters).fit(ar_coef_)
+            kmeans = KMeans(n_clusters=n_clusters,
+                            random_state=random_state).fit(ar_coef_)
             ar_coef_ = kmeans.cluster_centers_[kmeans.labels_]
 
             # Create a set of rounded values for the labels with _ between
@@ -216,6 +222,7 @@ def run_glm(Y, X, noise_model='ar1', bins=100, n_jobs=1, verbose=0):
     return labels, results
 
 
+@fill_doc
 class FirstLevelModel(BaseGLM):
     """ Implementation of the General Linear Model
     for single session fMRI data.
@@ -225,7 +232,7 @@ class FirstLevelModel(BaseGLM):
     t_r : float
         This parameter indicates repetition times of the experimental runs.
         In seconds. It is necessary to correctly consider times in the design
-        matrix. This parameter is also passed to nilearn.signal.clean.
+        matrix. This parameter is also passed to :func:`nilearn.signal.clean`.
         Please see the related documentation for details.
 
     slice_time_ref : float, optional
@@ -233,13 +240,8 @@ class FirstLevelModel(BaseGLM):
         slice timing preprocessing step of the experimental runs. It is
         expressed as a percentage of the t_r (time repetition), so it can have
         values between 0. and 1. Default=0.
-
-    hrf_model : {'glover', 'spm', 'spm + derivative', \
-            'spm + derivative + dispersion', 'glover + derivative', \
-            'glover + derivative + dispersion', 'fir', None}, optional
-        String that specifies the hemodynamic response function.
+    %(hrf_model)s
         Default='glover'.
-
     drift_model : string, optional
         This parameter specifies the desired drift model for the design
         matrices. It can be 'polynomial', 'cosine' or None.
@@ -276,12 +278,8 @@ class FirstLevelModel(BaseGLM):
     target_shape : 3-tuple of integers, optional
         This parameter is passed to nilearn.image.resample_img.
         Please see the related documentation for details.
-
-    smoothing_fwhm : float, optional
-        If smoothing_fwhm is not None, it gives the size in millimeters of
-        the spatial smoothing to apply to the signal.
-
-    memory : string, optional
+    %(smoothing_fwhm)s
+    memory : string or pathlib.Path, optional
         Path to the directory used to cache the masking process and the glm
         fit. By default, no caching is done.
         Creates instance of joblib.Memory.
@@ -330,6 +328,12 @@ class FirstLevelModel(BaseGLM):
         This id will be used to identify a `FirstLevelModel` when passed to
         a `SecondLevelModel` object.
 
+    random_state : int or numpy.random.RandomState, optional
+        Random state seed to sklearn.cluster.KMeans for autoregressive models
+        of order at least 2 ('ar(N)' with n >= 2). Default=None.
+
+        .. versionadded:: 0.9.1
+
     Attributes
     ----------
     labels_ : array of shape (n_voxels,),
@@ -341,19 +345,15 @@ class FirstLevelModel(BaseGLM):
         if minimize_memory is True,
         RegressionResults if minimize_memory is False
 
-    Notes
-    -----
-    This class is experimental.
-    It may change in any future release of Nilearn.
-
     """
+
     def __init__(self, t_r=None, slice_time_ref=0., hrf_model='glover',
                  drift_model='cosine', high_pass=.01, drift_order=1,
                  fir_delays=[0], min_onset=-24, mask_img=None,
                  target_affine=None, target_shape=None, smoothing_fwhm=None,
                  memory=Memory(None), memory_level=1, standardize=False,
                  signal_scaling=0, noise_model='ar1', verbose=0, n_jobs=1,
-                 minimize_memory=True, subject_label=None):
+                 minimize_memory=True, subject_label=None, random_state=None):
         # design matrix parameters
         self.t_r = t_r
         self.slice_time_ref = slice_time_ref
@@ -368,6 +368,7 @@ class FirstLevelModel(BaseGLM):
         self.target_affine = target_affine
         self.target_shape = target_shape
         self.smoothing_fwhm = smoothing_fwhm
+        memory = stringify_path(memory)
         if isinstance(memory, str):
             self.memory = Memory(memory)
         else:
@@ -377,8 +378,7 @@ class FirstLevelModel(BaseGLM):
         if signal_scaling is False:
             self.signal_scaling = signal_scaling
         elif signal_scaling in [0, 1, (0, 1)]:
-            self.scaling_axis = signal_scaling
-            self.signal_scaling = True
+            self.signal_scaling = signal_scaling
             self.standardize = False
         else:
             raise ValueError('signal_scaling must be "False", "0", "1"'
@@ -392,8 +392,17 @@ class FirstLevelModel(BaseGLM):
         self.labels_ = None
         self.results_ = None
         self.subject_label = subject_label
+        self.random_state = random_state
 
-    def fit(self, run_imgs, events=None, confounds=None,
+    @property
+    def scaling_axis(self):
+        warn(DeprecationWarning(
+            "Deprecated. `scaling_axis` will be removed in 0.11.0. "
+            "Please use `signal_scaling` instead."
+        ))
+        return self.signal_scaling
+
+    def fit(self, run_imgs, events=None, confounds=None, sample_masks=None,
             design_matrices=None, bins=100):
         """Fit the GLM
 
@@ -422,6 +431,15 @@ class FirstLevelModel(BaseGLM):
             respective run_img. Ignored in case designs is not None.
             If string, then a path to a csv file is expected.
 
+        sample_masks : array_like, or list of array_like, optional
+            shape of array: (number of scans - number of volumes removed, )
+            Indices of retained volumes. Masks the niimgs along time/fourth
+            dimension to perform scrubbing (remove volumes with high motion)
+            and/or remove non-steady-state volumes.
+            Default=None.
+
+            .. versionadded:: 0.9.2
+
         design_matrices : pandas DataFrame or \
                           list of pandas DataFrames, optional
             Design matrices that will be used to fit the GLM. If given it
@@ -446,7 +464,7 @@ class FirstLevelModel(BaseGLM):
                 'confounds and events will be ignored.'
             )
         # Local import to prevent circular imports
-        from nilearn.input_data import NiftiMasker  # noqa
+        from nilearn.maskers import NiftiMasker  # noqa
 
         # Check arguments
         # Check imgs type
@@ -470,6 +488,9 @@ class FirstLevelModel(BaseGLM):
         if confounds is not None:
             confounds = _check_run_tables(run_imgs, confounds, 'confounds')
 
+        if sample_masks is not None:
+            sample_masks = _check_run_sample_masks(len(run_imgs), sample_masks)
+
         # Learn the mask
         if self.mask_img is False:
             # We create a dummy mask to preserve functionality of api
@@ -559,6 +580,13 @@ class FirstLevelModel(BaseGLM):
                                                         )
             else:
                 design = design_matrices[run_idx]
+
+            if sample_masks is not None:
+                sample_mask = sample_masks[run_idx]
+                design = design.iloc[sample_mask, :]
+            else:
+                sample_mask = None
+
             self.design_matrices_.append(design)
 
             # Mask and prepare data for GLM
@@ -566,7 +594,7 @@ class FirstLevelModel(BaseGLM):
                 t_masking = time.time()
                 sys.stderr.write('Starting masker computation \r')
 
-            Y = self.masker_.transform(run_img)
+            Y = self.masker_.transform(run_img, sample_mask=sample_mask)
             del run_img  # Delete unmasked image to save memory
 
             if self.verbose > 1:
@@ -574,8 +602,8 @@ class FirstLevelModel(BaseGLM):
                 sys.stderr.write('Masker took %d seconds       \n'
                                  % t_masking)
 
-            if self.signal_scaling:
-                Y, _ = mean_scaling(Y, self.scaling_axis)
+            if self.signal_scaling is not False:  # noqa
+                Y, _ = mean_scaling(Y, self.signal_scaling)
             if self.memory:
                 mem_glm = self.memory.cache(run_glm, ignore=['n_jobs'])
             else:
@@ -587,7 +615,8 @@ class FirstLevelModel(BaseGLM):
                 sys.stderr.write('Performing GLM computation\r')
             labels, results = mem_glm(Y, design.values,
                                       noise_model=self.noise_model,
-                                      bins=bins, n_jobs=self.n_jobs)
+                                      bins=bins, n_jobs=self.n_jobs,
+                                      random_state=self.random_state)
             if self.verbose > 1:
                 t_glm = time.time() - t_glm
                 sys.stderr.write('GLM took %d seconds         \n' % t_glm)
@@ -620,18 +649,19 @@ class FirstLevelModel(BaseGLM):
             where ``n_col`` is the number of columns of the design matrix,
             (one array per run). If only one array is provided when there
             are several runs, it will be assumed that the same contrast is
-            desired for all runs. The string can be a formula compatible with
-            `pandas.DataFrame.eval`. Basically one can use the name of the
-            conditions as they appear in the design matrix of the fitted model
-            combined with operators +- and combined with numbers
-            with operators +-`*`/.
+            desired for all runs. One can use the name of the conditions as
+            they appear in the design matrix of the fitted model combined with
+            operators +- and combined with numbers with operators +-`*`/. In
+            this case, the string defining the contrasts must be a valid
+            expression for compatibility with :meth:`pandas.DataFrame.eval`.
 
         stat_type : {'t', 'F'}, optional
             Type of the contrast.
 
         output_type : str, optional
             Type of the output map. Can be 'z_score', 'stat', 'p_value',
-            'effect_size', 'effect_variance' or 'all'.
+            :term:`'effect_size'<Parameter Estimate>`, 'effect_variance' or
+            'all'.
             Default='z_score'.
 
         Returns
@@ -703,8 +733,8 @@ class FirstLevelModel(BaseGLM):
         ----------
         attribute : str
             an attribute of a RegressionResults instance.
-            possible values include: resid, norm_resid, predicted,
-            SSE, r_square, MSE.
+            possible values include: residuals, normalized_residuals,
+            predicted, SSE, r_square, MSE.
 
         result_as_time_series : bool
             whether the RegressionResult attribute has a value
@@ -762,49 +792,6 @@ class FirstLevelModel(BaseGLM):
 
         return output
 
-    @auto_attr
-    def residuals(self):
-        """Transform voxelwise residuals to the same shape
-        as the input Nifti1Image(s)
-
-        Returns
-        -------
-        output : list
-            A list of Nifti1Image(s).
-
-        """
-        return self._get_voxelwise_model_attribute('resid',
-                                                   result_as_time_series=True)
-
-    @auto_attr
-    def predicted(self):
-        """Transform voxelwise predicted values to the same shape
-        as the input Nifti1Image(s)
-
-        Returns
-        -------
-        output : list
-            A list of Nifti1Image(s).
-
-        """
-        return self._get_voxelwise_model_attribute('predicted',
-                                                   result_as_time_series=True)
-
-    @auto_attr
-    def r_square(self):
-        """Transform voxelwise r-squared values to the same shape
-        as the input Nifti1Image(s)
-
-        Returns
-        -------
-        output : list
-            A list of Nifti1Image(s).
-
-        """
-        return self._get_voxelwise_model_attribute('r_square',
-                                                   result_as_time_series=False
-                                                   )
-
 
 def first_level_from_bids(dataset_path, task_label, space_label=None,
                           img_filters=None, t_r=None, slice_time_ref=0.,
@@ -870,7 +857,7 @@ def first_level_from_bids(dataset_path, task_label, space_label=None,
 
     """
     # check arguments
-    img_filters = img_filters if img_filters else []
+    img_filters = img_filters or []
     if not isinstance(dataset_path, str):
         raise TypeError(
             'dataset_path must be a string, instead %s was given' %
