@@ -3,6 +3,7 @@ Test the first level model.
 """
 import os
 import shutil
+import unittest.mock
 
 import numpy as np
 import pandas as pd
@@ -11,11 +12,12 @@ from nibabel import Nifti1Image, load
 from nibabel.tmpdirs import InTemporaryDirectory
 from numpy.testing import (assert_almost_equal, assert_array_almost_equal,
                            assert_array_equal, assert_array_less)
+from sklearn.cluster import KMeans
 
 from nilearn._utils.data_gen import (create_fake_bids_dataset,
                                      generate_fake_fmri_data_and_design,
-                                     write_fake_fmri_data_and_design)
-from nilearn._utils.glm import get_bids_files
+                                     write_fake_fmri_data_and_design,
+                                     basic_paradigm)
 from nilearn.glm.contrasts import compute_fixed_effects
 from nilearn.glm.first_level import (FirstLevelModel, first_level_from_bids,
                                      mean_scaling, run_glm)
@@ -23,8 +25,10 @@ from nilearn.glm.first_level.design_matrix import (
     check_design_matrix, make_first_level_design_matrix)
 from nilearn.glm.first_level.first_level import _yule_walker
 from nilearn.image import get_data
+from nilearn.interfaces.bids import get_bids_files
 from nilearn.glm.regression import ARModel, OLSModel
-from nilearn.input_data import NiftiMasker
+from nilearn.maskers import NiftiMasker
+
 
 BASEDIR = os.path.dirname(os.path.abspath(__file__))
 FUNCFILE = os.path.join(BASEDIR, 'functional.nii.gz')
@@ -386,6 +390,25 @@ def test_glm_AR_estimates():
         _yule_walker(np.array(0.), 2)
 
 
+@pytest.mark.parametrize("random_state", [3, np.random.RandomState(42)])
+def test_glm_random_state(random_state):
+    rng = np.random.RandomState(42)
+    n, p, q = 33, 80, 10
+    X, Y = rng.standard_normal(size=(p, q)), rng.standard_normal(size=(p, n))
+
+    with unittest.mock.patch.object(
+        KMeans,
+        "__init__",
+        autospec=True,
+        side_effect=KMeans.__init__,
+    ) as spy_kmeans:
+        run_glm(Y, X, 'ar3', random_state=random_state)
+        spy_kmeans.assert_called_once_with(
+            unittest.mock.ANY,
+            n_clusters=unittest.mock.ANY,
+            random_state=random_state)
+
+
 def test_scaling():
     """Test the scaling function"""
     rng = np.random.RandomState(42)
@@ -470,16 +493,6 @@ def test_fmri_inputs():
         del fi, func_img, mask, d, des, FUNCFILE, _
 
 
-def basic_paradigm():
-    conditions = ['c0', 'c0', 'c0', 'c1', 'c1', 'c1', 'c2', 'c2', 'c2']
-    onsets = [30, 70, 100, 10, 30, 90, 30, 40, 60]
-    durations = 1 * np.ones(9)
-    events = pd.DataFrame({'trial_type': conditions,
-                           'onset': onsets,
-                           'duration': durations})
-    return events
-
-
 def test_first_level_design_creation():
     # Test processing of FMRI inputs
     with InTemporaryDirectory():
@@ -707,6 +720,32 @@ def test_first_level_from_bids():
                 bids_path, 'main', 'T1w')  # desc not specified
 
 
+def test_first_level_with_scaling():
+    shapes, rk = [(3, 1, 1, 2)], 1
+    fmri_data = list()
+    fmri_data.append(Nifti1Image(np.zeros((1, 1, 1, 2)) + 6, np.eye(4)))
+    design_matrices = list()
+    design_matrices.append(
+        pd.DataFrame(
+            np.ones((shapes[0][-1], rk)),
+            columns=list('abcdefghijklmnopqrstuvwxyz')[:rk])
+    )
+    fmri_glm = FirstLevelModel(
+        mask_img=False, noise_model='ols', signal_scaling=0,
+        minimize_memory=True
+    )
+    assert fmri_glm.signal_scaling == 0
+    assert not fmri_glm.standardize
+    with pytest.warns(DeprecationWarning,
+                      match="Deprecated. `scaling_axis` will be removed"):
+        assert fmri_glm.scaling_axis == 0
+    glm_parameters = fmri_glm.get_params()
+    test_glm = FirstLevelModel(**glm_parameters)
+    fmri_glm = fmri_glm.fit(fmri_data, design_matrices=design_matrices)
+    test_glm = test_glm.fit(fmri_data, design_matrices=design_matrices)
+    assert glm_parameters['signal_scaling'] == 0
+
+
 def test_first_level_with_no_signal_scaling():
     """
     test to ensure that the FirstLevelModel works correctly with a
@@ -796,7 +835,7 @@ def test_get_voxelwise_attributes_should_return_as_many_as_design_matrices(shape
     model.fit(fmri_data, design_matrices=design_matrices)
 
     # Check that length of outputs is the same as the number of design matrices
-    assert len(model._get_voxelwise_model_attribute("resid", True)) == \
+    assert len(model._get_voxelwise_model_attribute("residuals", True)) == \
            len(shapes)
 
 
@@ -825,3 +864,62 @@ def test_first_level_predictions_r_square():
 
     r_square_2d = model.masker_.transform(r_square_3d)
     assert_array_less(0., r_square_2d)
+
+
+@pytest.mark.parametrize("hrf_model", [
+    "spm",
+    "spm + derivative",
+    "glover",
+    lambda tr, ov: np.ones(int(tr * ov))
+])
+@pytest.mark.parametrize("spaces", [
+    False,
+    True
+])
+def test_first_level_hrf_model(hrf_model, spaces):
+    """
+    Ensure that FirstLevelModel runs without raising errors
+    for different values of hrf_model. In particular, one checks that it runs
+    without raising errors when given a custom response function.
+    When :meth:`~nilearn.glm.first_level.FirstLevelModel.compute_contrast`
+    is used errors should be raised when event (ie condition) names are not
+    valid identifiers.
+    """
+    shapes, rk = [(10, 10, 10, 25)], 3
+    mask, fmri_data, _ =\
+        generate_fake_fmri_data_and_design(shapes, rk)
+
+    events = basic_paradigm(condition_names_have_spaces=spaces)
+
+    model = FirstLevelModel(t_r=2.0,
+                            mask_img=mask,
+                            hrf_model=hrf_model)
+
+    model.fit(fmri_data, events)
+
+    columns = model.design_matrices_[0].columns
+    exp = f"{columns[0]}-{columns[1]}"
+    try:
+        model.compute_contrast(exp)
+    except Exception:
+        with pytest.raises(
+                ValueError,
+                match='invalid python identifiers'
+        ):
+            model.compute_contrast(exp)
+
+
+def test_glm_sample_mask():
+    """Ensure the sample mask is performing correctly in GLM."""
+    shapes, rk = [(10, 10, 10, 25)], 3
+    mask, fmri_data, design_matrix =\
+        generate_fake_fmri_data_and_design(shapes, rk)
+    model = FirstLevelModel(t_r=2.0,
+                            mask_img=mask,
+                            minimize_memory=False)
+    sample_mask = np.arange(25)[3:]  # censor the first three volumes
+    model.fit(fmri_data,
+              design_matrices=design_matrix,
+              sample_masks=sample_mask)
+    assert model.design_matrices_[0].shape[0] == 22
+    assert model.predicted[0].shape[-1] == 22
