@@ -1,8 +1,6 @@
 """
 Test the second level model.
 """
-from __future__ import with_statement
-
 import os
 
 import numpy as np
@@ -16,12 +14,13 @@ from nibabel import (load,
 from nibabel.tmpdirs import InTemporaryDirectory
 from numpy.testing import (assert_almost_equal,
                            assert_array_equal,
+                           assert_array_almost_equal,
                            )
 
 from nilearn._utils.data_gen import (write_fake_fmri_data_and_design,
                                      generate_fake_fmri_data_and_design)
 from nilearn.image import concat_imgs, get_data
-from nilearn.input_data import NiftiMasker
+from nilearn.maskers import NiftiMasker
 from nilearn.glm.first_level import (FirstLevelModel, run_glm)
 from nilearn.glm.second_level import (SecondLevelModel,
                                       non_parametric_inference)
@@ -31,6 +30,54 @@ BASEDIR = os.path.dirname(os.path.abspath(__file__))
 FUNCFILE = os.path.join(BASEDIR, 'functional.nii.gz')
 
 
+@pytest.fixture
+def input_df():
+    """Input DataFrame for testing."""
+    return pd.DataFrame({'effects_map_path': ["foo.nii", "bar.nii", "baz.nii"],
+                         'subject_label': ["foo", "bar", "baz"]})
+
+
+def test_process_second_level_input_as_dataframe(input_df):
+    """Unit tests for function _process_second_level_input_as_dataframe()."""
+    from nilearn.glm.second_level.second_level import _process_second_level_input_as_dataframe  # noqa
+    sample_map, subjects_label = _process_second_level_input_as_dataframe(
+        input_df
+    )
+    assert sample_map == "foo.nii"
+    assert subjects_label == ["foo", "bar", "baz"]
+
+
+def test_sort_input_dataframe(input_df):
+    """Unit tests for function _sort_input_dataframe()."""
+    from nilearn.glm.second_level.second_level import _sort_input_dataframe
+    output_df = _sort_input_dataframe(input_df)
+    assert output_df['subject_label'].values.tolist() == ["bar", "baz", "foo"]
+    assert(
+        output_df['effects_map_path'].values.tolist()
+        == ["bar.nii", "baz.nii", "foo.nii"]
+    )
+
+
+def test_process_second_level_input_as_firstlevelmodels():
+    """Unit tests for function
+    _process_second_level_input_as_firstlevelmodels().
+    """
+    from nilearn.glm.second_level.second_level import _process_second_level_input_as_firstlevelmodels  # noqa
+    shapes, rk = [(7, 8, 9, 15)], 3
+    mask, fmri_data, design_matrices = \
+        generate_fake_fmri_data_and_design(shapes, rk)
+    list_of_flm = [
+        FirstLevelModel(mask_img=mask, subject_label=f"sub-{i}").fit(
+            fmri_data[0], design_matrices=design_matrices[0]
+        ) for i in range(3)
+    ]
+    sample_map, subjects_label =\
+        _process_second_level_input_as_firstlevelmodels(list_of_flm)
+    assert subjects_label == [f"sub-{i}" for i in range(3)]
+    assert isinstance(sample_map, Nifti1Image)
+    assert sample_map.shape == (7, 8, 9)
+
+
 def test_check_second_level_input():
     from nilearn.glm.second_level.second_level import _check_second_level_input
     with pytest.raises(ValueError,
@@ -91,6 +138,12 @@ def test_check_second_level_input():
     with pytest.raises(ValueError,
                        match="second_level_input must be a list"):
         _check_second_level_input(1, None, flm_object=False)
+    with pytest.raises(ValueError,
+                       match="Contradictory arguments: flm_object is set to "
+                             "False yet second_level_input is a list of "
+                             "FirstLevelModel objects"):
+        _check_second_level_input([FirstLevelModel()] * 3, None,
+                                  flm_object=False, df_object=False)
 
 
 def test_check_output_type():
@@ -242,21 +295,32 @@ def test_high_level_non_parametric_inference_with_paths():
         shapes = ((7, 8, 9, 1),)
         mask, FUNCFILE, _ = write_fake_fmri_data_and_design(shapes)
         FUNCFILE = FUNCFILE[0]
+        df_input = pd.DataFrame(
+            {'subject_label': [f'sub-{i}' for i in range(4)],
+             'effects_map_path': [FUNCFILE] * 4,
+             'map_name': [FUNCFILE] * 4}
+        )
         func_img = load(FUNCFILE)
         Y = [func_img] * 4
         X = pd.DataFrame([[1]] * 4, columns=['intercept'])
         c1 = np.eye(len(X.columns))[0]
-        neg_log_pvals_img = non_parametric_inference(Y, design_matrix=X,
-                                                     second_level_contrast=c1,
-                                                     mask=mask, n_perm=n_perm,
-                                                     verbose=1)  # For coverage
-        neg_log_pvals = get_data(neg_log_pvals_img)
+        neg_log_pvals_imgs = [
+            non_parametric_inference(
+                second_level_input, design_matrix=X, second_level_contrast=c1,
+                first_level_contrast=FUNCFILE, mask=mask,
+                n_perm=n_perm, verbose=1
+            ) for second_level_input in [Y, df_input]
+        ]
+        assert all(
+            [isinstance(img, Nifti1Image) for img in neg_log_pvals_imgs]
+        )
+        for img in neg_log_pvals_imgs:
+            assert_array_equal(img.affine, load(mask).affine)
+        neg_log_pvals_list = [get_data(i) for i in neg_log_pvals_imgs]
+        for neg_log_pvals in neg_log_pvals_list:
+            assert np.all(neg_log_pvals <= - np.log10(1.0 / (n_perm + 1)))
+            assert np.all(0 <= neg_log_pvals)
 
-        assert isinstance(neg_log_pvals_img, Nifti1Image)
-        assert_array_equal(neg_log_pvals_img.affine, load(mask).affine)
-
-        assert np.all(neg_log_pvals <= - np.log10(1.0 / (n_perm + 1)))
-        assert np.all(0 <= neg_log_pvals)
         masker = NiftiMasker(mask, smoothing_fwhm=2.0)
         with pytest.warns(UserWarning,
                           match="Parameter smoothing_fwhm "
@@ -267,7 +331,7 @@ def test_high_level_non_parametric_inference_with_paths():
                                      mask=masker, n_perm=n_perm)
         # Delete objects attached to files to avoid WindowsError when deleting
         # temporary directory
-        del X, Y, FUNCFILE, func_img, neg_log_pvals_img
+        del X, Y, FUNCFILE, func_img, neg_log_pvals_imgs
 
 
 def test_fmri_inputs():
@@ -399,9 +463,6 @@ def test_fmri_inputs_for_non_parametric_inference():
         # test list of less than two niimgs
         with pytest.raises(ValueError):
             non_parametric_inference([FUNCFILE])
-        # test dataframe
-        with pytest.raises(ValueError):
-            non_parametric_inference(niidf)
         # test niimgs requirements
         with pytest.raises(ValueError):
             non_parametric_inference(niimgs)
@@ -450,6 +511,61 @@ def test_second_level_glm_computation():
         del func_img, FUNCFILE, model, X, Y
 
 
+@pytest.mark.parametrize("attribute", ["residuals", "predicted", "r_square"])
+def test_second_level_voxelwise_attribute_errors(attribute):
+    """Tests that an error is raised when trying to access
+    voxelwise attributes before fitting the model, before
+    computing a contrast, and when not setting
+    ``minimize_memory`` to ``True``.
+    """
+    shapes = ((7, 8, 9, 1),)
+    mask, fmri_data, _ = generate_fake_fmri_data_and_design(shapes)
+    model = SecondLevelModel(mask_img=mask, minimize_memory=False)
+    with pytest.raises(ValueError, match="The model has no results."):
+        getattr(model, attribute)
+    Y = fmri_data * 4
+    X = pd.DataFrame([[1]] * 4, columns=['intercept'])
+    model.fit(Y, design_matrix=X)
+    with pytest.raises(ValueError, match="The model has no results."):
+        getattr(model, attribute)
+    with pytest.raises(ValueError, match="attribute must be one of"):
+        model._get_voxelwise_model_attribute("foo", True)
+    model = SecondLevelModel(mask_img=mask, minimize_memory=True)
+    model.fit(Y, design_matrix=X)
+    model.compute_contrast()
+    with pytest.raises(ValueError,
+                       match="To access voxelwise attributes"):
+        getattr(model, attribute)
+
+
+@pytest.mark.parametrize("attribute", ["residuals", "predicted", "r_square"])
+def test_second_level_voxelwise_attribute(attribute):
+    """Smoke test for voxelwise attributes for SecondLevelModel."""
+    shapes = ((7, 8, 9, 1),)
+    mask, fmri_data, _ = generate_fake_fmri_data_and_design(shapes)
+    model = SecondLevelModel(mask_img=mask, minimize_memory=False)
+    Y = fmri_data * 4
+    X = pd.DataFrame([[1]] * 4, columns=['intercept'])
+    model.fit(Y, design_matrix=X)
+    model.compute_contrast()
+    getattr(model, attribute)
+
+
+def test_second_level_residuals():
+    """Tests residuals computation for SecondLevelModel."""
+    shapes = ((7, 8, 9, 1),)
+    mask, fmri_data, _ = generate_fake_fmri_data_and_design(shapes)
+    model = SecondLevelModel(mask_img=mask, minimize_memory=False)
+    Y = fmri_data * 4
+    X = pd.DataFrame([[1]] * 4, columns=['intercept'])
+    model.fit(Y, design_matrix=X)
+    model.compute_contrast()
+    assert isinstance(model.residuals, Nifti1Image)
+    assert model.residuals.shape == (7, 8, 9, 4)
+    mean_residuals = model.masker_.transform(model.residuals).mean(0)
+    assert_array_almost_equal(mean_residuals, 0)
+
+
 def test_non_parametric_inference_permutation_computation():
     with InTemporaryDirectory():
         shapes = ((7, 8, 9, 1),)
@@ -467,6 +583,62 @@ def test_non_parametric_inference_permutation_computation():
         del func_img, FUNCFILE, neg_log_pvals_img, X, Y
 
 
+def test_non_parametric_inference_tfce():
+    """Test non-parametric inference with TFCE inference."""
+    with InTemporaryDirectory():
+        shapes = [(7, 8, 9, 1)] * 4
+        mask, FUNCFILES, _ = write_fake_fmri_data_and_design(shapes)
+        X = pd.DataFrame([[1]] * 4, columns=['intercept'])
+
+        out = non_parametric_inference(
+            FUNCFILES,
+            design_matrix=X,
+            mask=mask,
+            n_perm=10,
+            tfce=True,
+        )
+        assert isinstance(out, dict)
+        assert 't' in out.keys()
+        assert 'tfce' in out.keys()
+        assert 'logp_max_t' in out.keys()
+        assert 'logp_max_tfce' in out.keys()
+
+        assert get_data(out['tfce']).shape == shapes[0][:3]
+        assert get_data(out['logp_max_tfce']).shape == shapes[0][:3]
+
+        del FUNCFILES, out, X
+
+
+def test_non_parametric_inference_cluster_level():
+    """Test non-parametric inference with cluster-level inference."""
+    with InTemporaryDirectory():
+        shapes = ((7, 8, 9, 1),)
+        mask, FUNCFILE, _ = write_fake_fmri_data_and_design(shapes)
+        FUNCFILE = FUNCFILE[0]
+        func_img = load(FUNCFILE)
+
+        Y = [func_img] * 4
+        X = pd.DataFrame([[1]] * 4, columns=['intercept'])
+
+        out = non_parametric_inference(
+            Y,
+            design_matrix=X,
+            mask=mask,
+            n_perm=10,
+            threshold=0.001,
+        )
+        assert isinstance(out, dict)
+        assert "t" in out.keys()
+        assert "logp_max_t" in out.keys()
+        assert "size" in out.keys()
+        assert "logp_max_size" in out.keys()
+        assert "mass" in out.keys()
+        assert "logp_max_mass" in out.keys()
+
+        assert get_data(out["logp_max_t"]).shape == shapes[0][:3]
+        del func_img, FUNCFILE, out, X, Y
+
+
 def test_second_level_contrast_computation():
     with InTemporaryDirectory():
         shapes = ((7, 8, 9, 1),)
