@@ -1,12 +1,13 @@
 """
-Mathematical operations working on Niimg-like objects like -a (3+n)-D block of
+Mathematical operations working on Niimg-like objects like a (3+)D block of
 data, and an affine.
 """
 from .resampling import resample_img, resample_to_img, reorder_img, \
     coord_transform
 from .image import high_variance_confounds, smooth_img, crop_img, \
     mean_img, swap_img_hemispheres, index_img, iter_img, threshold_img, \
-    math_img, load_img, clean_img, largest_connected_component_img
+    binarize_img, \
+    math_img, load_img, clean_img, largest_connected_component_img, get_data
 from .image import new_img_like  # imported this way to avoid circular imports
 from .._utils.niimg_conversions import concat_niimgs as concat_imgs
 from .._utils.niimg import copy_img
@@ -15,5 +16,5 @@ __all__ = ['resample_img', 'resample_to_img', 'high_variance_confounds',
            'smooth_img', 'crop_img', 'mean_img', 'reorder_img',
            'swap_img_hemispheres', 'concat_imgs', 'copy_img',
            'index_img', 'iter_img', 'new_img_like', 'threshold_img',
-           'math_img', 'load_img', 'clean_img',
+           'math_img', 'binarize_img', 'load_img', 'clean_img', 'get_data',
            'largest_connected_component_img', 'coord_transform']
