@@ -13,15 +13,24 @@ import warnings
 import nibabel
 import numpy as np
 from joblib import Parallel, delayed
-from scipy import ndimage
+from scipy.ndimage import (
+    label,
+    gaussian_filter1d,
+    generate_binary_structure,
+)
 from scipy.stats import scoreatpercentile
 
 from .. import signal
-from .._utils import (_repr_niimgs, as_ndarray, check_niimg, check_niimg_3d,
-                      check_niimg_4d)
+from .._utils import (_repr_niimgs,
+                      as_ndarray,
+                      check_niimg,
+                      check_niimg_3d,
+                      check_niimg_4d,
+                      fill_doc)
 from .._utils.niimg import _get_data, _safe_get_data
 from .._utils.niimg_conversions import _check_same_fov, _index_img
 from .._utils.param_validation import check_threshold
+from .._utils.helpers import rename_parameters, stringify_path
 
 
 def get_data(img):
@@ -30,7 +39,7 @@ def get_data(img):
     Parameters
     ----------
     img : Niimg-like object or iterable of Niimg-like objects
-        See http://nilearn.github.io/manipulating_images/input_output.html.
+        See :ref:`extracting_data`.
 
     Returns
     -------
@@ -53,12 +62,12 @@ def high_variance_confounds(imgs, n_confounds=5, percentile=2.,
         ----------
         imgs : Niimg-like object
             4D image.
-            See http://nilearn.github.io/manipulating_images/input_output.html.
+            See :ref:`extracting_data`.
 
         mask_img : Niimg-like object
             If not provided, all voxels are used.
             If provided, confounds are extracted from voxels inside the mask.
-            See http://nilearn.github.io/manipulating_images/input_output.html.
+            See :ref:`extracting_data`.
 
         n_confounds : :obj:`int`, optional
             Number of confounds to return. Default=5.
@@ -161,6 +170,7 @@ def _fast_smooth_array(arr):
     return smoothed_arr
 
 
+@fill_doc
 def _smooth_array(arr, affine, fwhm=None, ensure_finite=True, copy=True):
     """Smooth images by applying a Gaussian filter.
 
@@ -176,20 +186,7 @@ def _smooth_array(arr, affine, fwhm=None, ensure_finite=True, copy=True):
         (4, 4) matrix, giving affine transformation for image. (3, 3) matrices
         are also accepted (only these coefficients are used).
         If `fwhm='fast'`, the affine is not used and can be None.
-
-    fwhm : scalar, :class:`numpy.ndarray`/:obj:`tuple`/:obj:`list`, 'fast' or None, optional
-        Smoothing strength, as a full-width at half maximum, in millimeters.
-        If a nonzero scalar is given, width is identical in all 3 directions.
-        A :class:`numpy.ndarray`, :obj:`tuple`, or :obj:`list` must have 3 elements,
-        giving the FWHM along each axis.
-        If any of the elements is zero or None, smoothing is not performed
-        along that axis.
-        If  `fwhm='fast'`, a fast smoothing will be performed with a filter
-        [0.2, 1, 0.2] in each direction and a normalisation
-        to preserve the local average value.
-        If fwhm is None, no filtering is performed (useful when just removal
-        of non-finite values is needed).
-
+    %(fwhm)s
     ensure_finite : :obj:`bool`, optional
         If True, replace every non-finite values (like NaNs) by zero before
         filtering. Default=True.
@@ -237,10 +234,11 @@ def _smooth_array(arr, affine, fwhm=None, ensure_finite=True, copy=True):
         sigma = fwhm / (fwhm_over_sigma_ratio * vox_size)
         for n, s in enumerate(sigma):
             if s > 0.0:
-                ndimage.gaussian_filter1d(arr, s, output=arr, axis=n)
+                gaussian_filter1d(arr, s, output=arr, axis=n)
     return arr
 
 
+@fill_doc
 def smooth_img(imgs, fwhm):
     """Smooth images by applying a Gaussian filter.
 
@@ -250,24 +248,9 @@ def smooth_img(imgs, fwhm):
     Parameters
     ----------
     imgs : Niimg-like object or iterable of Niimg-like objects
-        Image(s) to smooth (see
-        http://nilearn.github.io/manipulating_images/input_output.html
+        Image(s) to smooth (see :ref:`extracting_data`
         for a detailed description of the valid input types).
-
-    fwhm : scalar, :class:`numpy.ndarray`, 'fast' or None
-        Smoothing strength, as a Full-Width at Half Maximum (FWHM), in
-        millimeters.
-        If a scalar is given, width is identical on all three
-        directions. A :class:`numpy.ndarray` must have 3 elements, giving the FWHM
-        along each axis.
-        If `fwhm='fast'`, a fast smoothing will be performed with
-        a filter [0.2, 1, 0.2] in each direction and a normalisation
-        to preserve the scale.
-        If `fwhm` is None, no filtering is performed (useful when just removal
-        of non-finite values is needed).
-
-        In corner case situations, `fwhm` is simply kept to None when `fwhm` is
-        specified as `fwhm=0`.
+    %(fwhm)s
 
     Returns
     -------
@@ -279,6 +262,7 @@ def smooth_img(imgs, fwhm):
 
     # Use hasattr() instead of isinstance to workaround a Python 2.6/2.7 bug
     # See http://bugs.python.org/issue7624
+    imgs = stringify_path(imgs)
     if hasattr(imgs, "__iter__") \
        and not isinstance(imgs, str):
         single_img = False
@@ -310,7 +294,7 @@ def _crop_img_to(img, slices, copy=True):
     img : Niimg-like object
         Image to be cropped. If slices has less entries than `img` has dimensions,
         the slices will be applied to the first `len(slices)` dimensions (See
-        http://nilearn.github.io/manipulating_images/input_output.html).
+        :ref:`extracting_data`).
 
     slices : list of slices
         Defines the range of the crop.
@@ -362,9 +346,8 @@ def crop_img(img, rtol=1e-8, copy=True, pad=True, return_offset=False):
     Parameters
     ----------
     img : Niimg-like object
-        Image to be cropped (see
-        http://nilearn.github.io/manipulating_images/input_output.html
-        for a detailed description of the valid input types).
+        Image to be cropped (see :ref:`extracting_data` for a detailed
+        description of the valid input types).
 
     rtol : :obj:`float`, optional
         relative tolerance (with respect to maximal absolute value of the
@@ -463,7 +446,7 @@ def _pad_array(array, pad_sizes):
                                           upper_paddings,
                                           new_shape)]
 
-    padded[tuple(target_slices)] = array[source_slices].copy()
+    padded[tuple(target_slices)] = array[tuple(source_slices)].copy()
     return padded
 
 
@@ -511,8 +494,7 @@ def mean_img(imgs, target_affine=None, target_shape=None,
     Parameters
     ----------
     imgs : Niimg-like object or iterable of Niimg-like objects
-        Images to be averaged over time (see
-        http://nilearn.github.io/manipulating_images/input_output.html
+        Images to be averaged over time (see :ref:`extracting_data`
         for a detailed description of the valid input types).
 
     target_affine : :class:`numpy.ndarray`, optional
@@ -542,6 +524,7 @@ def mean_img(imgs, target_affine=None, target_shape=None,
     nilearn.image.math_img : For more general operations on images.
 
     """
+    imgs = stringify_path(imgs)
     is_str = isinstance(imgs, str)
     is_iterable = isinstance(imgs, collections.abc.Iterable)
     if is_str or not is_iterable:
@@ -582,9 +565,8 @@ def swap_img_hemispheres(img):
     Parameters
     ----------
     img : Niimg-like object
-        Images to swap (see
-        http://nilearn.github.io/manipulating_images/input_output.html
-        for a detailed description of the valid input types).
+        Images to swap (see :ref:`extracting_data` for a detailed description
+        of the valid input types).
 
     Returns
     -------
@@ -625,7 +607,7 @@ def index_img(imgs, index):
     Parameters
     ----------
     imgs : 4D Niimg-like object
-        See http://nilearn.github.io/manipulating_images/input_output.html.
+        See :ref:`extracting_data`.
 
     index : Any type compatible with numpy array indexing
         Used for indexing the 4D data array in the fourth dimension.
@@ -649,24 +631,24 @@ def index_img(imgs, index):
      >>> joint_mni_image = concat_imgs([datasets.load_mni152_template(),
      ...                                datasets.load_mni152_template()])
      >>> print(joint_mni_image.shape)
-     (99, 117, 95, 2)
+     (197, 233, 189, 2)
 
     We can now select one slice from the last dimension of this 4D-image::
 
      >>> single_mni_image = index_img(joint_mni_image, 1)
      >>> print(single_mni_image.shape)
-     (99, 117, 95)
+     (197, 233, 189)
 
     We can also select multiple frames using the `slice` constructor::
 
      >>> five_mni_images = concat_imgs([datasets.load_mni152_template()] * 5)
      >>> print(five_mni_images.shape)
-     (99, 117, 95, 5)
+     (197, 233, 189, 5)
 
      >>> first_three_images = index_img(five_mni_images,
      ...                                slice(0, 3))
      >>> print(first_three_images.shape)
-     (99, 117, 95, 3)
+     (197, 233, 189, 3)
 
     """
     imgs = check_niimg_4d(imgs)
@@ -682,7 +664,7 @@ def iter_img(imgs):
     Parameters
     ----------
     imgs : 4D Niimg-like object
-        See http://nilearn.github.io/manipulating_images/input_output.html.
+        See :ref:`extracting_data`.
 
     Returns
     -------
@@ -696,6 +678,33 @@ def iter_img(imgs):
     return check_niimg_4d(imgs, return_iterator=True)
 
 
+def _downcast_from_int64_if_possible(data):
+    """If `data` is 64-bit ints and can be converted to (signed) int 32,
+    return an int32 copy, otherwise return `data` itself."""
+    if data.dtype not in (np.int64, np.uint64):
+        return data
+    img_min, img_max = np.min(data), np.max(data)
+    type_info = np.iinfo(np.int32)
+    can_cast = type_info.min <= img_min and type_info.max >= img_max
+    if can_cast:
+        warnings.warn(
+            "Data array used to create a new image contains 64-bit ints. "
+            "This is likely due to creating the array with numpy and "
+            "passing `int` as the `dtype`. Many tools such as FSL and SPM "
+            "cannot deal with int64 in Nifti images, so for compatibility the "
+            "data has been converted to int32.",
+            stacklevel=3)
+        return data.astype("int32")
+    warnings.warn(
+        "Data array used to create a new image contains 64-bit ints, and "
+        "some values too large to store in 32-bit ints. The resulting image "
+        "thus contains 64-bit ints, which may cause some compatibility issues "
+        "with some other tools or an error when saving the image to a "
+        "Nifti file.",
+        stacklevel=3)
+    return data
+
+
 def new_img_like(ref_niimg, data, affine=None, copy_header=False):
     """Create a new image of the same class as the reference image
 
@@ -705,7 +714,11 @@ def new_img_like(ref_niimg, data, affine=None, copy_header=False):
         Reference image. The new image will be of the same type.
 
     data : :class:`numpy.ndarray`
-        Data to be stored in the image.
+        Data to be stored in the image. If data dtype is a boolean, then data
+        is cast to 'uint8' by default.
+
+    .. versionchanged:: 0.9.2
+        Changed default dtype casting of booleans from 'int8' to 'uint8'.
 
     affine : 4x4 :class:`numpy.ndarray`, optional
         Transformation matrix.
@@ -717,7 +730,8 @@ def new_img_like(ref_niimg, data, affine=None, copy_header=False):
     Returns
     -------
     Niimg-like object
-        A loaded image with the same type (and header) as the reference image.
+        A loaded image with the same file type (and, optionally, header)
+        as the reference image.
 
     """
     # Hand-written loading code to avoid too much memory consumption
@@ -743,10 +757,8 @@ def new_img_like(ref_niimg, data, affine=None, copy_header=False):
     if affine is None:
         affine = ref_niimg.affine
     if data.dtype == bool:
-        default_dtype = np.int8
-        if isinstance(ref_niimg, nibabel.freesurfer.mghformat.MGHImage):
-            default_dtype = np.uint8
-        data = as_ndarray(data, dtype=default_dtype)
+        data = as_ndarray(data, dtype=np.uint8)
+    data = _downcast_from_int64_if_possible(data)
     header = None
     if copy_header:
         header = copy.deepcopy(ref_niimg.header)
@@ -775,18 +787,78 @@ def new_img_like(ref_niimg, data, affine=None, copy_header=False):
     return klass(data, affine, header=header)
 
 
-def threshold_img(img, threshold, mask_img=None, copy=True):
+def _apply_cluster_size_threshold(arr, cluster_threshold, copy=True):
+    """Apply cluster-extent thresholding to an array that has already been
+    voxel-wise thresholded.
+
+    Parameters
+    ----------
+    arr : :obj:`numpy.ndarray` of shape (X, Y, Z)
+        3D array that has been thresholded at the voxel level.
+    cluster_threshold : :obj:`float`
+        Cluster-size threshold, in voxels, to apply to ``arr``.
+    copy : :obj:`bool`, optional
+        Whether to copy the array before modifying it or not.
+        Default is True.
+
+    Returns
+    -------
+    arr : :obj:`numpy.ndarray` of shape (X, Y, Z)
+        Cluster-extent thresholded array.
+
+    Notes
+    -----
+    Clusters are defined in a bi-sided manner;
+    both negative and positive clusters are evaluated,
+    but this is done separately for each sign.
+
+    Clusters are defined using 6-connectivity, also known as NN1 (in AFNI) or
+    "faces" connectivity.
+    """
+    assert arr.ndim == 3
+
+    if copy:
+        arr = arr.copy()
+
+    # Define array for 6-connectivity, aka NN1 or "faces"
+    bin_struct = generate_binary_structure(3, 1)
+
+    for sign in np.unique(np.sign(arr)):
+        # Binarize using one-sided cluster-defining threshold
+        binarized = ((arr * sign) > 0).astype(int)
+
+        # Apply cluster threshold
+        label_map = label(binarized, bin_struct)[0]
+        clust_ids = sorted(list(np.unique(label_map)[1:]))
+        for c_val in clust_ids:
+            if np.sum(label_map == c_val) < cluster_threshold:
+                arr[label_map == c_val] = 0
+
+    return arr
+
+
+def threshold_img(
+    img,
+    threshold,
+    cluster_threshold=0,
+    two_sided=True,
+    mask_img=None,
+    copy=True,
+):
     """Threshold the given input image, mostly statistical or atlas images.
 
     Thresholding can be done based on direct image intensities or selection
     threshold with given percentile.
 
+    .. versionchanged:: 0.9.0
+        New ``cluster_threshold`` and ``two_sided`` parameters added.
+
     .. versionadded:: 0.2
 
     Parameters
     ----------
     img : a 3D/4D Niimg-like object
-        Image contains of statistical or atlas maps which should be thresholded.
+        Image containing statistical or atlas maps which should be thresholded.
 
     threshold : :obj:`float` or :obj:`str`
         If float, we threshold the image based on image intensities meaning
@@ -798,6 +870,20 @@ def threshold_img(img, threshold, mask_img=None, copy=True):
         voxels which have intensities greater than this score will be kept.
         The given string should be within the range of "0%" to "100%".
 
+    cluster_threshold : :obj:`float`, optional
+        Cluster size threshold, in voxels. In the returned thresholded map,
+        sets of connected voxels (``clusters``) with size smaller
+        than this number will be removed. Default=0.
+
+        .. versionadded:: 0.9.0
+
+    two_sided : :obj:`bool`, optional
+        Whether the thresholding should yield both positive and negative
+        part of the maps.
+        Default=True.
+
+        .. versionadded:: 0.9.0
+
     mask_img : Niimg-like object, default None, optional
         Mask image applied to mask the input data.
         If None, no masking will be applied.
@@ -813,7 +899,9 @@ def threshold_img(img, threshold, mask_img=None, copy=True):
 
     See also
     --------
-    nilearn.glm.threshold_stats_img
+    nilearn.glm.threshold_stats_img :
+        Threshold a statistical image using the alpha value, optionally with
+        false positive control.
 
     """
     from . import resampling
@@ -834,18 +922,40 @@ def threshold_img(img, threshold, mask_img=None, copy=True):
         # Set as 0 for the values which are outside of the mask
         img_data[mask_data == 0.] = 0.
 
-    if threshold is None:
-        raise ValueError("The input parameter 'threshold' is empty. "
-                         "Please give either a float value or a string as e.g. '90%'.")
+    cutoff_threshold = check_threshold(
+        threshold,
+        img_data,
+        percentile_func=scoreatpercentile,
+        name='threshold',
+    )
+
+    # Apply threshold
+    if two_sided:
+        img_data[np.abs(img_data) < cutoff_threshold] = 0.
     else:
-        cutoff_threshold = check_threshold(threshold, img_data,
-                                           percentile_func=scoreatpercentile,
-                                           name='threshold')
+        img_data[img_data < cutoff_threshold] = 0.
 
-    img_data[np.abs(img_data) < cutoff_threshold] = 0.
-    threshold_img = new_img_like(img, img_data, affine)
+    # Expand to 4D to support both 3D and 4D
+    expand_to_4d = img_data.ndim == 3
+    if expand_to_4d:
+        img_data = img_data[:, :, :, None]
 
-    return threshold_img
+    # Perform cluster thresholding, if requested
+    if cluster_threshold > 0:
+        for i_vol in range(img_data.shape[3]):
+            img_data[..., i_vol] = _apply_cluster_size_threshold(
+                img_data[..., i_vol],
+                cluster_threshold,
+            )
+
+    if expand_to_4d:
+        # Reduce back to 3D
+        img_data = img_data[:, :, :, 0]
+
+    # Reconstitute img object
+    thresholded_img = new_img_like(img, img_data, affine)
+
+    return thresholded_img
 
 
 def math_img(formula, **imgs):
@@ -984,7 +1094,8 @@ def binarize_img(img, threshold=0, mask_img=None):
     )
 
 
-def clean_img(imgs, sessions=None, detrend=True, standardize=True,
+@rename_parameters({'sessions': 'runs'}, '0.10.0')
+def clean_img(imgs, runs=None, detrend=True, standardize=True,
               confounds=None, low_pass=None, high_pass=None, t_r=None,
               ensure_finite=False, mask_img=None):
     """Improve SNR on masked fMRI signals.
@@ -1013,13 +1124,20 @@ def clean_img(imgs, sessions=None, detrend=True, standardize=True,
     ----------
     imgs : Niimg-like object
         4D image. The signals in the last dimension are filtered (see
-        http://nilearn.github.io/manipulating_images/input_output.html
-        for a detailed description of the valid input types).
+        :ref:`extracting_data` for a detailed description of the valid input
+        types).
 
-    sessions : :class:`numpy.ndarray`, optional
-        Add a session level to the cleaning process. Each session will be
+    runs : :class:`numpy.ndarray`, optional
+        Add a run level to the cleaning process. Each run will be
         cleaned independently. Must be a 1D array of n_samples elements.
 
+        .. warning::
+
+            'runs' replaces 'sessions' after release 0.10.0.
+            Using 'session' will result in an error after release 0.10.0.
+
+        Default=``None``.
+
     detrend : :obj:`bool`, optional
         If detrending should be applied on timeseries (before confound removal).
         Default=True.
@@ -1055,7 +1173,7 @@ def clean_img(imgs, sessions=None, detrend=True, standardize=True,
         If provided, signal is only cleaned from voxels inside the mask. If
         mask is provided, it should have same shape and affine as imgs.
         If not provided, all voxels are used.
-        See http://nilearn.github.io/manipulating_images/input_output.html.
+        See :ref:`extracting_data`.
 
     Returns
     -------
@@ -1065,10 +1183,10 @@ def clean_img(imgs, sessions=None, detrend=True, standardize=True,
     Notes
     -----
     Confounds removal is based on a projection on the orthogonal
-    of the signal space [:footcite:`friston1994statistical`].
+    of the signal space [:footcite:`Friston1994`].
 
     Orthogonalization between temporal filters and confound removal is based on
-    suggestions in [:footcite:`Lindquist407676`].
+    suggestions in [:footcite:`Lindquist2018`].
 
     References
     ----------
@@ -1104,7 +1222,7 @@ def clean_img(imgs, sessions=None, detrend=True, standardize=True,
 
     # Clean signal
     data = signal.clean(
-        signals, sessions=sessions, detrend=detrend, standardize=standardize,
+        signals, runs=runs, detrend=detrend, standardize=standardize,
         confounds=confounds, low_pass=low_pass, high_pass=high_pass, t_r=t_r,
         ensure_finite=ensure_finite)
 
@@ -1130,7 +1248,7 @@ def load_img(img, wildcards=True, dtype=None):
         on it. The '~' symbol is expanded to the user home folder.
         If it is an object, check if affine attribute is present, raise
         `TypeError` otherwise.
-        See http://nilearn.github.io/manipulating_images/input_output.html.
+        See :ref:`extracting_data`.
 
     wildcards : :obj:`bool`, optional
         Use `img` as a regular expression to get a list of matching input
@@ -1166,7 +1284,7 @@ def largest_connected_component_img(imgs):
     ----------
     imgs : Niimg-like object or iterable of Niimg-like objects (3D)
         Image(s) to extract the largest connected component from.
-        See http://nilearn.github.io/manipulating_images/input_output.html.
+        See :ref:`extracting_data`.
 
     Returns
     -------
@@ -1183,7 +1301,7 @@ def largest_connected_component_img(imgs):
 
     """
     from .._utils.ndimage import largest_connected_component
-
+    imgs = stringify_path(imgs)
     if hasattr(imgs, "__iter__") and not isinstance(imgs, str):
         single_img = False
     else:
