@@ -2,9 +2,8 @@
 Plotting code for nilearn
 """
 # Original Authors: Chris Filo Gorgolewski, Gael Varoquaux
-import os
-import sys
 import importlib
+import warnings
 
 
 ###############################################################################
@@ -29,13 +28,17 @@ def _set_mpl_backend():
                                           OPTIONAL_MATPLOTLIB_MIN_VERSION)
         current_backend = matplotlib.get_backend().lower()
 
-        if 'inline' in current_backend or 'nbagg' in current_backend:
-            return
-        # Set the backend to a non-interactive one for unices without X
-        # (see gh-2560)
-        if (sys.platform not in ('darwin', 'win32') and
-                'DISPLAY' not in os.environ):
-            matplotlib.use('Agg')
+        try:
+            # Making sure the current backend is usable by matplotlib
+            matplotlib.use(current_backend)
+        except Exception:
+            # If not, switching to default agg backend
+            matplotlib.use("Agg")
+        new_backend = matplotlib.get_backend().lower()
+
+        if new_backend != current_backend:
+            # Matplotlib backend has been changed, let's warn the user
+            warnings.warn(f"Backend changed to {new_backend}...")
 
 
 _set_mpl_backend()
@@ -44,8 +47,8 @@ _set_mpl_backend()
 from . import cm
 from .img_plotting import (
     plot_img, plot_anat, plot_epi, plot_roi, plot_stat_map,
-    plot_glass_brain, plot_connectome, plot_connectome_strength,
-    plot_markers, plot_prob_atlas, plot_carpet, plot_img_comparison, show)
+    plot_glass_brain, plot_connectome, plot_markers, plot_prob_atlas,
+    plot_carpet, plot_img_comparison, show)
 from .find_cuts import find_xyz_cut_coords, find_cut_slices, \
     find_parcellation_cut_coords, find_probabilistic_atlas_cut_coords
 from .matrix_plotting import (plot_matrix, plot_contrast_matrix,
@@ -68,5 +71,4 @@ __all__ = ['cm', 'plot_img', 'plot_anat', 'plot_epi',
            'find_parcellation_cut_coords',
            'find_probabilistic_atlas_cut_coords',
            'plot_surf', 'plot_surf_stat_map', 'plot_surf_roi',
-           'plot_img_on_surf', 'plot_connectome_strength', 'plot_carpet',
-           'plot_surf_contours']
+           'plot_img_on_surf', 'plot_carpet', 'plot_surf_contours']
