@@ -1,50 +1,272 @@
 # Tests for functions in surf_plotting.py
 import numpy as np
 import nibabel
+from matplotlib.figure import Figure
 import matplotlib.pyplot as plt
 import pytest
 import re
 import tempfile
+import os
+import unittest.mock as mock
 
 from nilearn.plotting.img_plotting import MNI152TEMPLATE
 from nilearn.plotting.surf_plotting import (plot_surf, plot_surf_stat_map,
                                             plot_surf_roi, plot_img_on_surf,
-                                            plot_surf_contours)
+                                            plot_surf_contours,
+                                            _get_ticks_matplotlib)
 from nilearn.datasets import fetch_surf_fsaverage
 from nilearn.surface import load_surf_mesh
 from nilearn.surface.testing_utils import generate_surf
 from numpy.testing import assert_array_equal
+from nilearn.plotting.surf_plotting import VALID_HEMISPHERES, VALID_VIEWS
+from nilearn.plotting.displays import PlotlySurfaceFigure
+
+try:
+    import plotly.graph_objects as go  # noqa
+except ImportError:
+    PLOTLY_INSTALLED = False
+else:
+    PLOTLY_INSTALLED = True
+
+try:
+    import kaleido  # noqa
+except ImportError:
+    KALEIDO_INSTALLED = False
+else:
+    KALEIDO_INSTALLED = True
+
+try:
+    import IPython.display  # noqa
+except ImportError:
+    IPYTHON_INSTALLED = False
+else:
+    IPYTHON_INSTALLED = True
+
+EXPECTED_CAMERAS_PLOTLY = {"left": {"anterior": "anterior",
+                                    "posterior": "posterior",
+                                    "medial": "right",
+                                    "lateral": "left",
+                                    "dorsal": "dorsal",
+                                    "ventral": "ventral"},
+                           "right": {"anterior": "anterior",
+                                     "posterior": "posterior",
+                                     "medial": "left",
+                                     "lateral": "right",
+                                     "dorsal": "dorsal",
+                                     "ventral": "ventral"}}
 
 
-def test_plot_surf():
+EXPECTED_VIEW_MATPLOTLIB = {"left": {"anterior": (0, 90),
+                                     "posterior": (0, 270),
+                                     "medial": (0, 0),
+                                     "lateral": (0, 180),
+                                     "dorsal": (90, 0),
+                                     "ventral": (270, 0)},
+                            "right": {"anterior": (0, 90),
+                                      "posterior": (0, 270),
+                                      "medial": (0, 180),
+                                      "lateral": (0, 0),
+                                      "dorsal": (90, 0),
+                                      "ventral": (270, 0)}}
+
+
+@pytest.fixture
+def expected_cameras_plotly(hemi, view):
+    return EXPECTED_CAMERAS_PLOTLY[hemi][view]
+
+
+@pytest.mark.parametrize("hemi", VALID_HEMISPHERES)
+@pytest.mark.parametrize("view", VALID_VIEWS)
+def test_set_view_plot_surf_plotly(hemi, view, expected_cameras_plotly):
+    from nilearn.plotting.surf_plotting import _set_view_plot_surf_plotly
+    assert _set_view_plot_surf_plotly(hemi, view) == expected_cameras_plotly
+
+
+@pytest.fixture
+def expected_view_matplotlib(hemi, view):
+    return EXPECTED_VIEW_MATPLOTLIB[hemi][view]
+
+
+@pytest.mark.parametrize("hemi", VALID_HEMISPHERES)
+@pytest.mark.parametrize("view", VALID_VIEWS)
+def test_set_view_plot_surf_matplotlib(hemi, view, expected_view_matplotlib):
+    from nilearn.plotting.surf_plotting import _set_view_plot_surf_matplotlib
+    assert(_set_view_plot_surf_matplotlib(hemi, view)
+           == expected_view_matplotlib)
+
+
+def test_surface_figure():
+    from nilearn.plotting.displays import SurfaceFigure
+    s = SurfaceFigure()
+    assert s.output_file is None
+    assert s.figure is None
+    with pytest.raises(NotImplementedError):
+        s.show()
+    with pytest.raises(ValueError, match="You must provide an output file"):
+        s._check_output_file()
+    s._check_output_file("foo.png")
+    assert s.output_file == "foo.png"
+    s = SurfaceFigure(output_file="bar.png")
+    assert s.output_file == "bar.png"
+
+
+@pytest.mark.skipif(PLOTLY_INSTALLED,
+                    reason='Plotly is installed.')
+def test_plotly_surface_figure_import_error():
+    """Test that an ImportError is raised when instantiating a
+    PlotlySurfaceFigure without having Plotly installed.
+    """
+    with pytest.raises(ImportError, match="Plotly is required"):
+        PlotlySurfaceFigure()
+
+
+@pytest.mark.skipif(not PLOTLY_INSTALLED or KALEIDO_INSTALLED,
+                    reason=("This test only runs if Plotly is "
+                            "installed, but not kaleido."))
+def test_plotly_surface_figure_savefig_error():
+    """Test that an ImportError is raised when saving a
+    PlotlySurfaceFigure without having kaleido installed.
+    """
+    with pytest.raises(ImportError, match="`kaleido` is required"):
+        PlotlySurfaceFigure().savefig()
+
+
+@pytest.mark.skipif(not PLOTLY_INSTALLED or not KALEIDO_INSTALLED,
+                    reason=("Plotly and/or kaleido not installed; "
+                            "required for this test."))
+def test_plotly_surface_figure():
+    ps = PlotlySurfaceFigure()
+    assert ps.output_file is None
+    assert ps.figure is None
+    ps.show()
+    with pytest.raises(ValueError, match="You must provide an output file"):
+        ps.savefig()
+    ps.savefig('foo.png')
+
+
+@pytest.mark.skipif(not PLOTLY_INSTALLED or not IPYTHON_INSTALLED,
+                    reason=("Plotly and/or Ipython is not installed; "
+                            "required for this test."))
+@pytest.mark.parametrize("renderer", ['png', 'jpeg', 'svg'])
+def test_plotly_show(renderer):
+    ps = PlotlySurfaceFigure(go.Figure())
+    assert ps.output_file is None
+    assert ps.figure is not None
+    with mock.patch("IPython.display.display") as mock_display:
+        ps.show(renderer=renderer)
+    assert len(mock_display.call_args.args) == 1
+    key = 'svg+xml' if renderer == 'svg' else renderer
+    assert f'image/{key}' in mock_display.call_args.args[0]
+
+
+@pytest.mark.skipif(not PLOTLY_INSTALLED or not KALEIDO_INSTALLED,
+                    reason=("Plotly and/or kaleido not installed; "
+                            "required for this test."))
+def test_plotly_savefig(tmpdir):
+    ps = PlotlySurfaceFigure(go.Figure(), output_file=str(tmpdir / "foo.png"))
+    assert ps.output_file == str(tmpdir / "foo.png")
+    assert ps.figure is not None
+    ps.savefig()
+    assert os.path.exists(str(tmpdir / "foo.png"))
+
+
+@pytest.mark.skipif(not PLOTLY_INSTALLED,
+                    reason='Plotly is not installed; required for this test.')
+@pytest.mark.parametrize("input_obj", ["foo", Figure(), ["foo", "bar"]])
+def test_instantiation_error_plotly_surface_figure(input_obj):
+    with pytest.raises(TypeError,
+                       match=("`PlotlySurfaceFigure` accepts only "
+                              "plotly figure objects.")):
+        PlotlySurfaceFigure(input_obj)
+
+
+def test_set_view_plot_surf_errors():
+    from nilearn.plotting.surf_plotting import (_set_view_plot_surf_matplotlib,
+                                                _set_view_plot_surf_plotly)
+    with pytest.raises(ValueError,
+                       match="hemi must be one of"):
+        _set_view_plot_surf_matplotlib("foo", "medial")
+        _set_view_plot_surf_plotly("bar", "anterior")
+    with pytest.raises(ValueError,
+                       match="view must be one of"):
+        _set_view_plot_surf_matplotlib("left", "foo")
+        _set_view_plot_surf_matplotlib("right", "bar")
+        _set_view_plot_surf_plotly("left", "foo")
+        _set_view_plot_surf_plotly("right", "bar")
+
+
+def test_configure_title_plotly():
+    from nilearn.plotting.surf_plotting import _configure_title_plotly
+    assert _configure_title_plotly(None, None) == dict()
+    assert _configure_title_plotly(None, 22) == dict()
+    config = _configure_title_plotly("Test Title", 22, color="green")
+    assert config["text"] == "Test Title"
+    assert config["x"] == 0.5
+    assert config["y"] == 0.96
+    assert config["xanchor"] == "center"
+    assert config["yanchor"] == "top"
+    assert config["font"]["size"] == 22
+    assert config["font"]["color"] == "green"
+
+
+@pytest.mark.parametrize("data,expected",
+                         [(np.linspace(0, 1, 100), (0, 1)),
+                          (np.linspace(-.7, -.01, 40), (-.7, -.01))])
+def test_get_bounds(data, expected):
+    from nilearn.plotting.surf_plotting import _get_bounds
+    assert _get_bounds(data) == expected
+    assert _get_bounds(data, vmin=.2) == (.2, expected[1])
+    assert _get_bounds(data, vmax=.8) == (expected[0], .8)
+    assert _get_bounds(data, vmin=.1, vmax=.8) == (.1, .8)
+
+
+def test_plot_surf_engine_error():
+    mesh = generate_surf()
+    with pytest.raises(ValueError,
+                       match="Unknown plotting engine"):
+        plot_surf(mesh, engine="foo")
+
+
+@pytest.mark.parametrize("engine", ["matplotlib", "plotly"])
+def test_plot_surf(engine, tmp_path):
+    if not PLOTLY_INSTALLED and engine == "plotly":
+        pytest.skip('Plotly is not installed; required for this test.')
     mesh = generate_surf()
     rng = np.random.RandomState(42)
     bg = rng.standard_normal(size=mesh[0].shape[0])
 
     # Plot mesh only
-    plot_surf(mesh)
+    plot_surf(mesh, engine=engine)
 
     # Plot mesh with background
-    plot_surf(mesh, bg_map=bg)
-    plot_surf(mesh, bg_map=bg, darkness=0.5)
-    plot_surf(mesh, bg_map=bg, alpha=0.5)
+    plot_surf(mesh, bg_map=bg, engine=engine)
+    plot_surf(mesh, bg_map=bg, darkness=0.5, engine=engine)
+    plot_surf(mesh, bg_map=bg, alpha=0.5,
+              output_file=tmp_path / 'tmp.png', engine=engine)
 
     # Plot different views
-    plot_surf(mesh, bg_map=bg, hemi='right')
-    plot_surf(mesh, bg_map=bg, view='medial')
-    plot_surf(mesh, bg_map=bg, hemi='right', view='medial')
+    plot_surf(mesh, bg_map=bg, hemi='right', engine=engine)
+    plot_surf(mesh, bg_map=bg, view='medial', engine=engine)
+    plot_surf(mesh, bg_map=bg, hemi='right', view='medial', engine=engine)
 
     # Plot with colorbar
-    plot_surf(mesh, bg_map=bg, colorbar=True)
+    plot_surf(mesh, bg_map=bg, colorbar=True, engine=engine)
     plot_surf(mesh, bg_map=bg, colorbar=True, cbar_vmin=0,
-              cbar_vmax=150, cbar_tick_format="%i")
+              cbar_vmax=150, cbar_tick_format="%i", engine=engine)
+    # Save execution time and memory
+    plt.close()
 
     # Plot with title
-    display = plot_surf(mesh, bg_map=bg, title='Test title')
-    assert display._suptitle._text == 'Test title'
-    assert display._suptitle._x == .5
-    assert display._suptitle._y == .95
+    display = plot_surf(mesh, bg_map=bg, title='Test title',
+                        engine=engine)
+    if engine == 'matplotlib':
+        assert len(display.axes) == 1
+        assert display.axes[0].title._text == 'Test title'
 
+
+def test_plot_surf_avg_method():
+    mesh = generate_surf()
+    rng = np.random.RandomState(42)
     # Plot with avg_method
     ## Test all built-in methods and check
     mapp = rng.standard_normal(size=mesh[0].shape[0])
@@ -52,7 +274,9 @@ def test_plot_surf():
     coords, faces = mesh_[0], mesh_[1]
 
     for method in ['mean', 'median', 'min', 'max']:
-        display = plot_surf(mesh, surf_map=mapp, avg_method=method)
+        display = plot_surf(mesh, surf_map=mapp,
+                            avg_method=method,
+                            engine='matplotlib')
         if method == 'mean':
             agg_faces = np.mean(mapp[faces], axis=1)
         elif method == 'median':
@@ -65,56 +289,69 @@ def test_plot_surf():
         vmax = np.max(agg_faces)
         agg_faces -= vmin
         agg_faces /= (vmax - vmin)
-        cmap = plt.cm.get_cmap(plt.rcParamsDefault['image.cmap'])
+        cmap = plt.get_cmap(plt.rcParamsDefault['image.cmap'])
         assert_array_equal(
             cmap(agg_faces),
             display._axstack.as_list()[0].collections[0]._facecolors
         )
-
     ## Try custom avg_method
     def custom_avg_function(vertices):
         return vertices[0] * vertices[1] * vertices[2]
     plot_surf(
         mesh,
         surf_map=rng.standard_normal(size=mesh[0].shape[0]),
-        avg_method=custom_avg_function
+        avg_method=custom_avg_function,
+        engine='matplotlib',
     )
-
     # Save execution time and memory
     plt.close()
 
 
-def test_plot_surf_error():
+@pytest.mark.parametrize("engine", ["matplotlib", "plotly"])
+def test_plot_surf_error(engine):
+    if not PLOTLY_INSTALLED and engine == "plotly":
+        pytest.skip('Plotly is not installed; required for this test.')
     mesh = generate_surf()
     rng = np.random.RandomState(42)
 
     # Wrong inputs for view or hemi
     with pytest.raises(ValueError, match='view must be one of'):
-        plot_surf(mesh, view='middle')
+        plot_surf(mesh, view='middle', engine=engine)
     with pytest.raises(ValueError, match='hemi must be one of'):
-        plot_surf(mesh, hemi='lft')
+        plot_surf(mesh, hemi='lft', engine=engine)
 
     # Wrong size of background image
     with pytest.raises(
             ValueError,
             match='bg_map does not have the same number of vertices'):
-        plot_surf(mesh, bg_map=rng.standard_normal(size=mesh[0].shape[0] - 1))
+        plot_surf(mesh,
+                  bg_map=rng.standard_normal(size=mesh[0].shape[0] - 1),
+                  engine=engine
+                  )
 
     # Wrong size of surface data
     with pytest.raises(
         ValueError, match="surf_map does not have the same number of vertices"
     ):
         plot_surf(
-            mesh, surf_map=rng.standard_normal(size=mesh[0].shape[0] + 1)
+            mesh,
+            surf_map=rng.standard_normal(size=mesh[0].shape[0] + 1),
+            engine=engine
         )
 
     with pytest.raises(
-        ValueError, match="surf_map can only have one dimension"
+        ValueError, match="'surf_map' can only have one dimension"
     ):
         plot_surf(
-            mesh, surf_map=rng.standard_normal(size=(mesh[0].shape[0], 2))
+            mesh,
+            surf_map=rng.standard_normal(size=(mesh[0].shape[0], 2)),
+            engine=engine
         )
 
+
+def test_plot_surf_avg_method_errors():
+    mesh = generate_surf()
+    rng = np.random.RandomState(42)
     with pytest.raises(
         ValueError,
         match=(
@@ -126,7 +363,12 @@ def test_plot_surf_error():
         def custom_avg_function(vertices):
             return [vertices[0] * vertices[1], vertices[2]]
 
-        plot_surf(mesh, surf_map=rng.standard_normal(size=mesh[0].shape[0]), avg_method=custom_avg_function)
+        plot_surf(mesh,
+                  surf_map=rng.standard_normal(
+                      size=mesh[0].shape[0]),
+                  avg_method=custom_avg_function,
+                  engine='matplotlib'
+                  )
 
     with pytest.raises(
         ValueError,
@@ -138,7 +380,19 @@ def test_plot_surf_error():
     ):
         custom_avg_function = dict()
 
-        plot_surf(mesh, surf_map=rng.standard_normal(size=mesh[0].shape[0]), avg_method=custom_avg_function)
+        plot_surf(mesh,
+                  surf_map=rng.standard_normal(
+                      size=mesh[0].shape[0]),
+                  avg_method=custom_avg_function,
+                  engine='matplotlib'
+                  )
+
+        plot_surf(mesh,
+                  surf_map=rng.standard_normal(
+                      size=mesh[0].shape[0]),
+                  avg_method="foo",
+                  engine='matplotlib'
+                  )
 
     with pytest.raises(
         ValueError,
@@ -151,53 +405,71 @@ def test_plot_surf_error():
         def custom_avg_function(vertices):
             return "string"
 
-        plot_surf(mesh, surf_map=rng.standard_normal(size=mesh[0].shape[0]), avg_method=custom_avg_function)
+        plot_surf(mesh,
+                  surf_map=rng.standard_normal(
+                      size=mesh[0].shape[0]),
+                  avg_method=custom_avg_function,
+                  engine='matplotlib'
+                  )
 
-def test_plot_surf_stat_map():
+
+@pytest.mark.parametrize("engine", ["matplotlib", "plotly"])
+def test_plot_surf_stat_map(engine):
+    if not PLOTLY_INSTALLED and engine == "plotly":
+        pytest.skip('Plotly is not installed; required for this test.')
     mesh = generate_surf()
     rng = np.random.RandomState(42)
     bg = rng.standard_normal(size=mesh[0].shape[0])
     data = 10 * rng.standard_normal(size=mesh[0].shape[0])
 
     # Plot mesh with stat map
-    plot_surf_stat_map(mesh, stat_map=data)
-    plot_surf_stat_map(mesh, stat_map=data, colorbar=True)
-    plot_surf_stat_map(mesh, stat_map=data, alpha=1)
+    plot_surf_stat_map(mesh, stat_map=data, engine=engine)
+    plot_surf_stat_map(mesh, stat_map=data, colorbar=True, engine=engine)
+    plot_surf_stat_map(mesh, stat_map=data, alpha=1, engine=engine)
 
     # Plot mesh with background and stat map
-    plot_surf_stat_map(mesh, stat_map=data, bg_map=bg)
+    plot_surf_stat_map(mesh, stat_map=data, bg_map=bg, engine=engine)
     plot_surf_stat_map(mesh, stat_map=data, bg_map=bg,
-                       bg_on_data=True, darkness=0.5)
+                       bg_on_data=True, darkness=0.5,
+                       engine=engine)
     plot_surf_stat_map(mesh, stat_map=data, bg_map=bg, colorbar=True,
-                       bg_on_data=True, darkness=0.5)
+                       bg_on_data=True, darkness=0.5, engine=engine)
 
     # Plot with title
     display = plot_surf_stat_map(mesh, stat_map=data, bg_map=bg,
                                  title="Stat map title")
-    assert display._suptitle._text == "Stat map title"
-    assert display._suptitle._x == .5
-    assert display._suptitle._y == .95
+    assert display.axes[0].title._text == "Stat map title"
 
     # Apply threshold
     plot_surf_stat_map(mesh, stat_map=data, bg_map=bg,
                        bg_on_data=True, darkness=0.5,
-                       threshold=0.3)
+                       threshold=0.3, engine=engine)
     plot_surf_stat_map(mesh, stat_map=data, bg_map=bg, colorbar=True,
                        bg_on_data=True, darkness=0.5,
-                       threshold=0.3)
+                       threshold=0.3, engine=engine)
 
     # Change colorbar tick format
     plot_surf_stat_map(mesh, stat_map=data, bg_map=bg, colorbar=True,
-                       bg_on_data=True, darkness=0.5, cbar_tick_format="%.2g")
+                       bg_on_data=True, darkness=0.5, cbar_tick_format="%.2g",
+                       engine=engine)
 
     # Change vmax
-    plot_surf_stat_map(mesh, stat_map=data, vmax=5)
-    plot_surf_stat_map(mesh, stat_map=data, vmax=5, colorbar=True)
+    plot_surf_stat_map(mesh, stat_map=data, vmax=5, engine=engine)
+    plot_surf_stat_map(mesh, stat_map=data, vmax=5,
+                       colorbar=True, engine=engine)
 
     # Change colormap
-    plot_surf_stat_map(mesh, stat_map=data, cmap='cubehelix')
-    plot_surf_stat_map(mesh, stat_map=data, cmap='cubehelix', colorbar=True)
+    plot_surf_stat_map(mesh, stat_map=data, cmap='cubehelix', engine=engine)
+    plot_surf_stat_map(mesh, stat_map=data, cmap='cubehelix',
+                       colorbar=True, engine=engine)
 
+    plt.close()
+
+
+def test_plot_surf_stat_map_matplotlib_specific():
+    mesh = generate_surf()
+    rng = np.random.RandomState(42)
+    data = 10 * rng.standard_normal(size=mesh[0].shape[0])
     # Plot to axes
     axes = plt.subplots(ncols=2, subplot_kw={'projection': '3d'})[1]
     for ax in axes.flatten():
@@ -231,11 +503,11 @@ def test_plot_surf_stat_map():
     # Add nan values in the texture
     data[2] = np.nan
     # Plot the surface stat map
-    ax = plot_surf_stat_map(mesh, stat_map=data)
+    fig = plot_surf_stat_map(mesh, stat_map=data)
     # Check that the resulting plot facecolors contain no transparent faces
     # (last column equals zero) even though the texture contains nan values
     assert(mesh[1].shape[0] ==
-            ((ax._axstack.as_list()[0].collections[0]._facecolors[:, 3]) != 0).sum())
+            ((fig._axstack.as_list()[0].collections[0]._facecolors[:, 3]) != 0).sum())  # noqa
 
     # Save execution time and memory
     plt.close()
@@ -260,24 +532,44 @@ def test_plot_surf_stat_map_error():
 
     with pytest.raises(
             ValueError,
-            match='surf_map can only have one dimension'):
+            match="'surf_map' can only have one dimension"):
         plot_surf_stat_map(mesh, stat_map=np.vstack((data, data)).T)
 
 
-def test_plot_surf_roi():
+def _generate_data_test_surf_roi():
     mesh = generate_surf()
     rng = np.random.RandomState(42)
     roi_idx = rng.randint(0, mesh[0].shape[0], size=10)
     roi_map = np.zeros(mesh[0].shape[0])
     roi_map[roi_idx] = 1
     parcellation = rng.uniform(size=mesh[0].shape[0])
+    return mesh, roi_map, parcellation
 
+
+@pytest.mark.parametrize("engine", ["matplotlib", "plotly"])
+def test_plot_surf_roi(engine):
+    if not PLOTLY_INSTALLED and engine == "plotly":
+        pytest.skip('Plotly is not installed; required for this test.')
+    mesh, roi_map, parcellation = _generate_data_test_surf_roi()
     # plot roi
-    plot_surf_roi(mesh, roi_map=roi_map)
-    plot_surf_roi(mesh, roi_map=roi_map, colorbar=True)
+    plot_surf_roi(mesh, roi_map=roi_map, engine=engine)
+    plot_surf_roi(mesh, roi_map=roi_map,
+                  colorbar=True, engine=engine)
+    # plot parcellation
+    plot_surf_roi(mesh, roi_map=parcellation, engine=engine)
+    plot_surf_roi(mesh, roi_map=parcellation, colorbar=True,
+                  engine=engine)
+    plot_surf_roi(mesh, roi_map=parcellation, colorbar=True,
+                  cbar_tick_fomat="%f", engine=engine)
+    plt.close()
+
+
+def test_plot_surf_roi_matplotlib_specific():
+    mesh, roi_map, parcellation = _generate_data_test_surf_roi()
     # change vmin, vmax
     img = plot_surf_roi(mesh, roi_map=roi_map, vmin=1.2,
-                        vmax=8.9, colorbar=True)
+                        vmax=8.9, colorbar=True,
+                        engine='matplotlib')
     img.canvas.draw()
     cbar = img.axes[-1]
     cbar_vmin = float(cbar.get_yticklabels()[0].get_text())
@@ -285,33 +577,33 @@ def test_plot_surf_roi():
     assert cbar_vmin == 1.0
     assert cbar_vmax == 8.0
     img2 = plot_surf_roi(mesh, roi_map=roi_map, vmin=1.2,
-                         vmax=8.9, colorbar=True, cbar_tick_format="%.2g")
+                         vmax=8.9, colorbar=True,
+                         cbar_tick_format="%.2g",
+                         engine='matplotlib')
     img2.canvas.draw()
     cbar = img2.axes[-1]
     cbar_vmin = float(cbar.get_yticklabels()[0].get_text())
     cbar_vmax = float(cbar.get_yticklabels()[-1].get_text())
     assert cbar_vmin == 1.2
     assert cbar_vmax == 8.9
-
-    # plot parcellation
-    plot_surf_roi(mesh, roi_map=parcellation)
-    plot_surf_roi(mesh, roi_map=parcellation, colorbar=True)
-    plot_surf_roi(mesh, roi_map=parcellation, colorbar=True, cbar_tick_fomat="%f")
-
     # plot to axes
-    plot_surf_roi(mesh, roi_map=roi_map, ax=None, figure=plt.gcf())
+    plot_surf_roi(mesh, roi_map=roi_map, ax=None,
+                  figure=plt.gcf(), engine='matplotlib')
 
     # plot to axes
     with tempfile.NamedTemporaryFile() as tmp_file:
-        plot_surf_roi(mesh, roi_map=roi_map, ax=plt.gca(), figure=None,
-                      output_file=tmp_file.name)
+        plot_surf_roi(mesh, roi_map=roi_map, ax=plt.gca(),
+                      figure=None, output_file=tmp_file.name,
+                      engine='matplotlib')
     with tempfile.NamedTemporaryFile() as tmp_file:
-        plot_surf_roi(mesh, roi_map=roi_map, ax=plt.gca(), figure=None,
-                      output_file=tmp_file.name, colorbar=True)
+        plot_surf_roi(mesh, roi_map=roi_map, ax=plt.gca(),
+                      figure=None, output_file=tmp_file.name,
+                      colorbar=True, engine='matplotlib')
 
     # Test nans handling
     parcellation[::2] = np.nan
-    img = plot_surf_roi(mesh, roi_map=parcellation)
+    img = plot_surf_roi(mesh, roi_map=parcellation,
+                        engine='matplotlib')
     # Check that the resulting plot facecolors contain no transparent faces
     # (last column equals zero) even though the texture contains nan values
     assert(mesh[1].shape[0] ==
@@ -320,14 +612,17 @@ def test_plot_surf_roi():
     plt.close()
 
 
-def test_plot_surf_roi_error():
+@pytest.mark.parametrize("engine", ["matplotlib", "plotly"])
+def test_plot_surf_roi_error(engine):
+    if not PLOTLY_INSTALLED and engine == "plotly":
+        pytest.skip('Plotly is not installed; required for this test.')
     mesh = generate_surf()
     rng = np.random.RandomState(42)
     roi_idx = rng.randint(0, mesh[0].shape[0], size=5)
     with pytest.raises(
             ValueError,
             match='roi_map does not have the same number of vertices'):
-        plot_surf_roi(mesh, roi_map=roi_idx)
+        plot_surf_roi(mesh, roi_map=roi_idx, engine=engine)
 
 
 def _generate_img():
@@ -488,16 +783,16 @@ def test_plot_surf_contours():
                                  labels=['1', '2'], colors=['r', 'g'],
                                  legend=True, title='title',
                                  figure=fig)
-    assert display._suptitle._text == 'title'
-    assert display._suptitle._x == .3
-    assert display._suptitle._y == .95
+    # Non-regression assertion: we switched from _suptitle to axis title
+    assert display._suptitle is None
+    assert display.axes[0].get_title() == "title"
     fig = plot_surf(mesh, title='title 2')
     display = plot_surf_contours(mesh, parcellation, levels=[1, 2],
                                  labels=['1', '2'], colors=['r', 'g'],
                                  legend=True, figure=fig)
-    assert display._suptitle._text == 'title 2'
-    assert display._suptitle._x == .3
-    assert display._suptitle._y == .95
+    # Non-regression assertion: we switched from _suptitle to axis title
+    assert display._suptitle is None
+    assert display.axes[0].get_title() == "title 2"
     with tempfile.NamedTemporaryFile() as tmp_file:
         plot_surf_contours(mesh, parcellation, output_file=tmp_file.name)
     plt.close()
@@ -528,3 +823,23 @@ def test_plot_surf_contours_error():
             ValueError,
             match='Levels, labels, and colors argument need to be either the same length or None.'):
         plot_surf_contours(mesh, parcellation, levels=[1, 2], colors=['r'], labels=['1', '2'])
+
+
+@pytest.mark.parametrize("vmin,vmax,cbar_tick_format,expected", [
+    (0, 0, "%i", [0]),
+    (0, 3, "%i", [0, 1, 2, 3]),
+    (0, 4, "%i", [0, 1, 2, 3, 4]),
+    (1, 5, "%i", [1, 2, 3, 4, 5]),
+    (0, 5, "%i", [0, 1.25, 2.5, 3.75, 5]),
+    (0, 10, "%i", [0, 2.5, 5, 7.5, 10]),
+    (0, 0, "%.1f", [0]),
+    (0, 1, "%.1f", [0, 0.25, 0.5, 0.75, 1]),
+    (1, 2, "%.1f", [1, 1.25, 1.5, 1.75, 2]),
+    (1.1, 1.2, "%.1f", [1.1, 1.125, 1.15, 1.175, 1.2]),
+    (0, np.nextafter(0, 1), "%.1f", [0.e+000, 5.e-324]),
+])
+def test_get_ticks_matplotlib(vmin, vmax, cbar_tick_format, expected):
+    ticks = _get_ticks_matplotlib(vmin, vmax, cbar_tick_format)
+    assert 1 <= len(ticks) <= 5
+    assert ticks[0] == vmin and ticks[-1] == vmax
+    assert len(ticks) == len(expected) and (ticks == expected).all()
