@@ -9,11 +9,13 @@ from sklearn.feature_extraction import image
 from joblib import Memory, delayed, Parallel
 
 from .rena_clustering import ReNA
-from ..decomposition.multi_pca import MultiPCA
-from ..input_data import NiftiLabelsMasker
+from .hierarchical_kmeans_clustering import HierarchicalKMeans
+from ..decomposition._multi_pca import _MultiPCA
+from nilearn.maskers import NiftiLabelsMasker
 from .._utils.niimg import _safe_get_data
 from .._utils.niimg_conversions import _iter_check_niimg
 from .._utils import fill_doc
+from .._utils import stringify_path
 
 
 def _estimator_fit(data, estimator, method=None):
@@ -27,7 +29,10 @@ def _estimator_fit(data, estimator, method=None):
     estimator : instance of estimator from sklearn
         MiniBatchKMeans or AgglomerativeClustering.
 
-    method : str, {'kmeans', 'ward', 'complete', 'average', 'rena'}, optional
+    method: str,
+    {'kmeans', 'ward', 'complete', 'average', 'rena', 'hierarchical_kmeans'},
+    optional
+
         A method to choose between for brain parcellations.
 
     Returns
@@ -61,6 +66,8 @@ def _check_parameters_transform(imgs, confounds):
     as a list.
 
     """
+    imgs = stringify_path(imgs)
+    confounds = stringify_path(confounds)
     if not isinstance(imgs, (list, tuple)) or \
             isinstance(imgs, str):
         imgs = [imgs, ]
@@ -112,7 +119,7 @@ def _labels_masker_extraction(img, masker, confound):
 
 
 @fill_doc
-class Parcellations(MultiPCA):
+class Parcellations(_MultiPCA):
     """Learn :term:`parcellations<parcellation>`
     on :term:`fMRI` images.
 
@@ -128,7 +135,8 @@ class Parcellations(MultiPCA):
 
     Parameters
     ----------
-    method : :obj:`str`, {'kmeans', 'ward', 'complete', 'average', 'rena'}
+    method: :obj:`str`, {'kmeans', 'ward', 'complete', 'average', 'rena',
+        'hierarchical_kmeans'}
         A method to choose between for brain parcellations.
         For a small number of parcels, kmeans is usually advisable.
         For a large number of parcellations (several hundreds, or thousands),
@@ -139,8 +147,8 @@ class Parcellations(MultiPCA):
     %(random_state)s
         Default=0.
 
-    mask : Niimg-like object or :class:`nilearn.input_data.NiftiMasker`,\
- :class:`nilearn.input_data.MultiNiftiMasker`, optional
+    mask : Niimg-like object or :class:`nilearn.maskers.NiftiMasker`,\
+ :class:`nilearn.maskers.MultiNiftiMasker`, optional
         Mask/Masker used for masking the data.
         If mask image if provided, it will be used in the MultiNiftiMasker.
         If an instance of MultiNiftiMasker is provided, then this instance
@@ -226,8 +234,8 @@ class Parcellations(MultiPCA):
     `labels_img_` : :class:`nibabel.nifti1.Nifti1Image`
         Labels image to each parcellation learned on fmri images.
 
-    `masker_` : :class:`nilearn.input_data.NiftiMasker` or\
- :class:`nilearn.input_data.MultiNiftiMasker`
+    `masker_` : :class:`nilearn.maskers.NiftiMasker` or\
+ :class:`nilearn.maskers.MultiNiftiMasker`
         The masker used to mask the data.
 
     `connectivity_` : :class:`numpy.ndarray`
@@ -248,7 +256,8 @@ class Parcellations(MultiPCA):
       giving the matrix.
 
     """
-    VALID_METHODS = ['kmeans', 'ward', 'complete', 'average', 'rena']
+    VALID_METHODS = ['kmeans', 'ward', 'complete',
+                     'average', 'rena', 'hierarchical_kmeans']
 
     def __init__(self, method, n_parcels=50,
                  random_state=0, mask=None, smoothing_fwhm=4.,
@@ -265,19 +274,19 @@ class Parcellations(MultiPCA):
         self.scaling = scaling
         self.n_iter = n_iter
 
-        MultiPCA.__init__(self, n_components=200,
-                          random_state=random_state,
-                          mask=mask, memory=memory,
-                          smoothing_fwhm=smoothing_fwhm,
-                          standardize=standardize, detrend=detrend,
-                          low_pass=low_pass, high_pass=high_pass,
-                          t_r=t_r, target_affine=target_affine,
-                          target_shape=target_shape,
-                          mask_strategy=mask_strategy,
-                          mask_args=mask_args,
-                          memory_level=memory_level,
-                          n_jobs=n_jobs,
-                          verbose=verbose)
+        _MultiPCA.__init__(self, n_components=200,
+                           random_state=random_state,
+                           mask=mask, memory=memory,
+                           smoothing_fwhm=smoothing_fwhm,
+                           standardize=standardize, detrend=detrend,
+                           low_pass=low_pass, high_pass=high_pass,
+                           t_r=t_r, target_affine=target_affine,
+                           target_shape=target_shape,
+                           mask_strategy=mask_strategy,
+                           mask_args=mask_args,
+                           memory_level=memory_level,
+                           n_jobs=n_jobs,
+                           verbose=verbose)
 
     def _raw_fit(self, data):
         """Fits the parcellation method on this reduced data.
@@ -324,7 +333,7 @@ class Parcellations(MultiPCA):
         except Exception:
             pass
 
-        components = MultiPCA._raw_fit(self, data)
+        components = _MultiPCA._raw_fit(self, data)
 
         mask_img_ = self.masker_.mask_img_
         if self.verbose:
@@ -339,6 +348,15 @@ class Parcellations(MultiPCA):
                                      verbose=max(0, self.verbose - 1))
             labels = self._cache(_estimator_fit,
                                  func_memory_level=1)(components.T, kmeans)
+        elif self.method == 'hierarchical_kmeans':
+            hkmeans = HierarchicalKMeans(self.n_parcels, init="k-means++",
+                                         batch_size=1000, n_init=10,
+                                         max_no_improvement=10,
+                                         random_state=self.random_state,
+                                         verbose=max(0, self.verbose - 1))
+            # data ou data.T
+            labels = self._cache(_estimator_fit,
+                                 func_memory_level=1)(components.T, hkmeans)
 
         elif self.method == 'rena':
             rena = ReNA(mask_img_, n_clusters=self.n_parcels,
