@@ -6,13 +6,13 @@ import numbers
 import collections.abc
 import numpy as np
 
-from scipy import ndimage
+from scipy.ndimage import label
 from scipy.stats import scoreatpercentile
 
 from joblib import Memory
 
 from .. import masking
-from ..input_data import NiftiMapsMasker
+from nilearn.maskers import NiftiMapsMasker
 from .._utils import (check_niimg, check_niimg_3d,
                       check_niimg_4d, fill_doc)
 from ..image import new_img_like, resample_img
@@ -149,11 +149,15 @@ def connected_regions(maps_img, min_region_size=1350,
         Minimum volume in mm3 for a region to be kept. For example, if the voxel
         size is 3x3x3 mm then the volume of the voxel is 27mm^3.
         Default=1350mm^3, which means we take minimum size of 1350 / 27 = 50 voxels.
-
     %(extract_type)s
-    smoothing_fwhm : :obj:`float`, optional
-        To smooth an image to extract most sparser regions. This parameter
-        is passed `_smooth_array` and exists only for extract_type 'local_regions'.
+    %(smoothing_fwhm)s
+        Use this parameter to smooth an image to extract most sparser regions.
+
+        .. note::
+
+            This parameter is passed to `nilearn.image.image._smooth_array`.
+            It will be used only if ``extract_type='local_regions'``.
+
         Default=6.
 
     mask_img : Niimg-like object, optional
@@ -210,7 +214,7 @@ def connected_regions(maps_img, min_region_size=1350,
         if extract_type == 'local_regions':
             smooth_map = _smooth_array(map_3d, affine=affine, fwhm=smoothing_fwhm)
             seeds = _peak_local_max(smooth_map)
-            seeds_label, seeds_id = ndimage.label(seeds)
+            seeds_label, seeds_id = label(seeds)
             # Assign -1 to values which are 0. to indicate to ignore
             seeds_label[map_3d == 0.] = -1
             rw_maps = _random_walker(map_3d, seeds_label)
@@ -219,7 +223,7 @@ def connected_regions(maps_img, min_region_size=1350,
             label_maps = rw_maps
         else:
             # Connected component extraction
-            label_maps, n_labels = ndimage.label(map_3d)
+            label_maps, n_labels = label(map_3d)
 
         # Takes the size of each labelized region data
         labels_size = np.bincount(label_maps.ravel())
@@ -249,7 +253,7 @@ class RegionExtractor(NiftiMapsMasker):
     Particularly, to show that each decomposed brain maps can be
     used to focus on a target specific Regions of Interest analysis.
 
-    See [1]_.
+    See :footcite:`Abraham2014`.
 
     .. versionadded:: 0.2
 
@@ -289,19 +293,27 @@ class RegionExtractor(NiftiMapsMasker):
         parameter indicates that we keep only those voxels which have
         intensities more than this value.
         Default='ratio_n_voxels'.
-
     %(extractor)s
-    smoothing_fwhm : :obj:`float`, optional
-        To smooth an image to extract most sparser regions. This parameter
-        is passed to `connected_regions` and exists only for extractor
-        'local_regions'. Please set this parameter according to maps
-        resolution, otherwise extraction will fail.
+    %(smoothing_fwhm)s
+        Use this parameter to smooth an image to extract most sparser regions.
+
+        .. note::
+
+            This parameter is passed to
+            :func:`nilearn.regions.connected_regions`.
+            It will be used only if ``extractor='local_regions'``.
+
+        .. note::
+
+            Please set this parameter according to maps resolution,
+            otherwise extraction will fail.
+
         Default=6mm.
     %(standardize_false)s
 
         .. note::
             Recommended to set to True if signals are not already standardized.
-            Passed to :class:`nilearn.input_data.NiftiMapsMasker`.
+            Passed to :class:`~nilearn.maskers.NiftiMapsMasker`.
 
     %(detrend)s
 
@@ -341,9 +353,7 @@ class RegionExtractor(NiftiMapsMasker):
 
     References
     ----------
-    .. [1] Abraham et al. "Region segmentation for sparse decompositions:
-       better brain parcellations from rest fMRI", Sparsity Techniques in
-       Medical Imaging, Sep 2014, Boston, United States. pp.8
+    .. footbibliography::
 
     See Also
     --------
@@ -508,17 +518,18 @@ def connected_label_regions(labels_img, min_size=None, connect_diag=True,
     else:
         this_labels = labels
 
-    new_labels_data = np.zeros(labels_data.shape, dtype=np.int)
+    new_labels_data = np.zeros(labels_data.shape, dtype=int)
     current_max_label = 0
     for label_id, name in zip(unique_labels, this_labels):
         this_label_mask = (labels_data == label_id)
         # Extract regions assigned to each label id
         if connect_diag:
-            structure = np.ones((3, 3, 3), dtype=np.int)
-            regions, this_n_labels = ndimage.label(
-                this_label_mask.astype(np.int), structure=structure)
+            structure = np.ones((3, 3, 3), dtype=int)
+            regions, this_n_labels = label(
+                this_label_mask.astype(int), structure=structure
+            )
         else:
-            regions, this_n_labels = ndimage.label(this_label_mask.astype(np.int))
+            regions, this_n_labels = label(this_label_mask.astype(int))
 
         if min_size is not None:
             index = np.arange(this_n_labels + 1)
