@@ -9,8 +9,7 @@ import warnings
 from scipy.sparse import csgraph, coo_matrix, dia_matrix
 from joblib import Memory
 
-from sklearn.base import TransformerMixin, ClusterMixin
-from sklearn.base import BaseEstimator
+from sklearn.base import BaseEstimator, TransformerMixin, ClusterMixin
 from sklearn.utils.validation import check_is_fitted
 from sklearn.utils import check_array
 from nilearn.masking import _unmask_from_to_3d_array
@@ -146,7 +145,7 @@ def _make_edges_and_weights(X, mask_img):
     return edges, weights
 
 
-def weighted_connectivity_graph(X, mask_img):
+def _weighted_connectivity_graph(X, mask_img):
     """Creating symmetric weighted graph: data and topology are encoded by a
     connectivity matrix.
 
@@ -284,7 +283,7 @@ def _reduce_data_and_connectivity(X, labels, n_components, connectivity,
     return reduced_connectivity, reduced_X
 
 
-def nearest_neighbor_grouping(X, connectivity, n_clusters, threshold=1e-7):
+def _nearest_neighbor_grouping(X, connectivity, n_clusters, threshold=1e-7):
     """Cluster using nearest neighbor agglomeration: merge clusters according
     to their nearest neighbors, then the data and the connectivity are reduced.
 
@@ -388,7 +387,7 @@ def recursive_neighbor_agglomeration(X, mask_img, n_clusters,
     .. footbibliography::
 
     """
-    connectivity = weighted_connectivity_graph(X, mask_img)
+    connectivity = _weighted_connectivity_graph(X, mask_img)
 
     # Initialization
     labels = np.arange(connectivity.shape[0])
@@ -396,7 +395,7 @@ def recursive_neighbor_agglomeration(X, mask_img, n_clusters,
 
     for i in range(n_iter):
 
-        connectivity, X, reduced_labels = nearest_neighbor_grouping(
+        connectivity, X, reduced_labels = _nearest_neighbor_grouping(
             X, connectivity, n_clusters, threshold)
 
         labels = reduced_labels[labels]
@@ -468,6 +467,9 @@ class ReNA(BaseEstimator, ClusterMixin, TransformerMixin):
         self.memory_level = memory_level
         self.verbose = verbose
 
+    def _more_tags(self):
+        return BaseEstimator._more_tags()
+
     def fit(self, X, y=None):
         """Compute clustering of the data.
 
@@ -493,7 +495,7 @@ class ReNA(BaseEstimator, ClusterMixin, TransformerMixin):
                              % type(self.mask_img))
 
         if self.memory is None or isinstance(self.memory, str):
-            self.memory_ = Memory(cachedir=self.memory,
+            self.memory_ = Memory(location=self.memory,
                                   verbose=max(0, self.verbose - 1))
         else:
             self.memory_ = self.memory
